Boost logo

Boost-Commit :

Subject: [Boost-commit] svn:boost r55455 - in sandbox/SOC/2009/unicode: boost/unicode boost/unicode/ucd libs/unicode/data_parser libs/unicode/example libs/unicode/src libs/unicode/src/ucd
From: loufoque_at_[hidden]
Date: 2009-08-07 23:06:03


Author: mgaunard
Date: 2009-08-07 23:06:01 EDT (Fri, 07 Aug 2009)
New Revision: 55455
URL: http://svn.boost.org/trac/boost/changeset/55455

Log:
Composition can only be canonical
Text files modified:
   sandbox/SOC/2009/unicode/boost/unicode/compose.hpp | 2
   sandbox/SOC/2009/unicode/boost/unicode/compose_fwd.hpp | 95 +--
   sandbox/SOC/2009/unicode/boost/unicode/hangul.hpp | 2
   sandbox/SOC/2009/unicode/boost/unicode/pipe_def.hpp | 4
   sandbox/SOC/2009/unicode/boost/unicode/ucd/properties.hpp | 7
   sandbox/SOC/2009/unicode/boost/unicode/ucd/properties_types.hpp | 2
   sandbox/SOC/2009/unicode/libs/unicode/data_parser/Jamfile.v2 | 5
   sandbox/SOC/2009/unicode/libs/unicode/data_parser/read_character_properties_unicodedata.cpp | 2
   sandbox/SOC/2009/unicode/libs/unicode/data_parser/write_character_properties.cpp | 56 +
   sandbox/SOC/2009/unicode/libs/unicode/example/compose.cpp | 7
   sandbox/SOC/2009/unicode/libs/unicode/src/ucd/uni_ucd_interface_impl_compose_data.ipp | 1082 ----------------------------------------
   sandbox/SOC/2009/unicode/libs/unicode/src/ucd/uni_ucd_interface_impl_data_7.ipp | 52
   sandbox/SOC/2009/unicode/libs/unicode/src/unicode_properties.cpp | 2
   13 files changed, 128 insertions(+), 1190 deletions(-)

Modified: sandbox/SOC/2009/unicode/boost/unicode/compose.hpp
==============================================================================
--- sandbox/SOC/2009/unicode/boost/unicode/compose.hpp (original)
+++ sandbox/SOC/2009/unicode/boost/unicode/compose.hpp 2009-08-07 23:06:01 EDT (Fri, 07 Aug 2009)
@@ -9,7 +9,7 @@
 namespace unicode
 {
 
-BOOST_UNICODE_PIPE_DEF(compose, 1)
+BOOST_UNICODE_PIPE_DEF(compose, 0)
 BOOST_UNICODE_ONE_MANY_PIPE_DEF(decompose, 1)
 
 } // namespace unicode

Modified: sandbox/SOC/2009/unicode/boost/unicode/compose_fwd.hpp
==============================================================================
--- sandbox/SOC/2009/unicode/boost/unicode/compose_fwd.hpp (original)
+++ sandbox/SOC/2009/unicode/boost/unicode/compose_fwd.hpp 2009-08-07 23:06:01 EDT (Fri, 07 Aug 2009)
@@ -7,17 +7,15 @@
 #include <boost/integer/static_pow.hpp>
 #include <climits>
 
-#include <boost/range/algorithm/copy.hpp>
-#include <boost/range/distance.hpp>
-#include <boost/range/adaptor/filtered.hpp>
-
+#include <boost/iterator/pipe_iterator.hpp>
 #include <vector>
 
 namespace boost
 {
 namespace unicode
 {
-
+
+/** Computes 2 elevated to power \c o so as to use the option within bit masks. */
 #define BOOST_UNICODE_OPTION(o) (boost::static_pow<2, (o)>::value)
 #ifdef BOOST_UNICODE_DOXYGEN_INVOKED
 #undef BOOST_UNICODE_OPTION
@@ -26,7 +24,7 @@
 /** Model of \c \xmlonly<conceptname>OneManyPipe</conceptname>\endxmlonly
  * that decomposes a code point, i.e. it converts a code point into a
  * sequence of code points.
- * It applies UCD decompositions that match \c mask as well as the Hangul decompositions. */
+ * It applies UCD decompositions that match \c mask recursively as well as the Hangul decompositions. */
 struct decomposer
 {
     typedef char32 input_type;
@@ -36,19 +34,22 @@
     {
     }
     
+ /** \post [<tt>begin</tt>, <tt>end</tt>[ is in Normalization Form D. */
     template<typename Out>
     Out operator()(char32 ch, Out out)
     {
- iterator_range<const char32*> dec = ucd::get_decomposition(ch);
- if(!empty(dec) && ((1 << ucd::get_decomposition_type(ch)) & mask))
+ if(ucd::get_combining_class(ch) != 0)
         {
- out = copy(dec, out);
+ // TODO: actually enforce the postcondition, canonical order is not guaranteed */
         }
- else
+
+ iterator_range<const char32*> dec = ucd::get_decomposition(ch);
+ if(!empty(dec) && ((1 << ucd::get_decomposition_type(ch)) & mask))
         {
- out = hangul_decomposer()(ch, out);
+ return pipe(dec, make_one_many_pipe(*this), out); // we decompose recursively
         }
- return out;
+
+ return hangul_decomposer()(ch, out);
     }
     
 private:
@@ -88,38 +89,21 @@
     private:
         std::size_t offset;
     };
-
- struct mask_compose_data_entry
- {
- mask_compose_data_entry(unsigned mask_) : mask(mask_)
- {
- }
-
- bool operator()(const ucd::unichar_compose_data_entry& entry) const
- {
- return ((1 << ucd::get_decomposition_type(entry.ch)) & mask) != 0;
- }
-
- private:
- unsigned mask;
- };
 }
 
 /** Model of \c \xmlonly<conceptname>Pipe</conceptname>\endxmlonly
  * that composes a sequence of code points, i.e. it converts a sequence
  * of code points into a single code point.
- * It applies UCD compositions that match \c mask as well as the Hangul
+ * It applies UCD canonical compositions as well as the Hangul
  * compositions, excluding the ones from the composition
  * exclusion table. */
 struct composer
 {
     typedef char32 input_type;
     typedef char32 output_type;
+ typedef mpl::int_<1> max_output;
     
- composer(unsigned mask_ = BOOST_UNICODE_OPTION(ucd::decomposition_type::canonical)) : mask(mask_)
- {
- }
-
+ /** \pre [<tt>begin</tt>, <tt>end</tt>[ is in Normalization Form D. */
     template<typename In, typename Out>
     std::pair<In, Out> ltr(In begin, In end, Out out)
     {
@@ -133,39 +117,37 @@
         std::size_t offset = 0;
         for(;;)
         {
- filter_range<
- detail::mask_compose_data_entry,
- const iterator_range<const ucd::unichar_compose_data_entry*>
- > r =
- make_filtered_range(
- make_iterator_range(
- std::equal_range(
- table_begin, table_end,
- pos,
- detail::composition_find<In>(offset)
- )
- ),
- detail::mask_compose_data_entry(mask)
+ const iterator_range<const ucd::unichar_compose_data_entry*> r =
+ std::equal_range(
+ table_begin, table_end,
+ pos,
+ detail::composition_find<In>(offset)
                 );
             
- std::ptrdiff_t sz = distance(r);
- if(sz == 1 && offset == (r.begin()->decomp[0]-1))
+ ++pos;
+ std::size_t sz = size(r);
+ if(sz == 0) // no possible match
+ {
+ return hangul_composer().ltr(begin, end, out);
+ }
+ else if( (sz == 1 || pos == end) && offset == (r.begin()->decomp[0]-1)) // a complete match was found
             {
                 *out++ = r.begin()->ch;
- return std::make_pair(++pos, out);
+ return std::make_pair(pos, out);
             }
- else if(sz == 0 || ++pos == end)
+ else if(pos == end) // some possible matches but none complete
             {
                 return hangul_composer().ltr(begin, end, out);
             }
             
- table_begin = r.begin().base();
- table_end = r.end().base();
+ table_begin = r.begin();
+ table_end = r.end();
             ++offset;
         }
     }
     
     /* This could by made faster using a sorted table of reversed strings */
+ /** \pre [<tt>begin</tt>, <tt>end</tt>[ is in Normalization Form D. */
     template<typename In, typename Out>
     std::pair<In, Out> rtl(In begin, In end, Out out)
     {
@@ -180,7 +162,7 @@
         /* First pass, we copy the possible results into a vector */
         for(const ucd::unichar_compose_data_entry* p = table_begin; p != table_end; ++p)
         {
- if(detail::mask_compose_data_entry(mask)(*p) && p->decomp[p->decomp[0]] == *pos)
+ if(p->decomp[p->decomp[0]] == *pos)
                 r.push_back(p);
         }
         
@@ -205,15 +187,16 @@
             for(iterator it = r.begin(); it != r.end(); ++it)
             {
                 const ucd::unichar_compose_data_entry* p = *it;
- if(detail::mask_compose_data_entry(mask)(*p) && p->decomp[0] > offset && p->decomp[p->decomp[0]-offset] == *pos)
+ if(
+ p->decomp[0] > offset &&
+ (pos == begin ? p->decomp[0] == offset+1 : true) && // if we are at the beginning, we only consider matches with the right size.
+ p->decomp[p->decomp[0]-offset] == *pos
+ )
                     r2.push_back(p);
             }
             r.swap(r2);
         }
     }
-
-private:
- unsigned mask;
 };
 
 } // namespace unicode

Modified: sandbox/SOC/2009/unicode/boost/unicode/hangul.hpp
==============================================================================
--- sandbox/SOC/2009/unicode/boost/unicode/hangul.hpp (original)
+++ sandbox/SOC/2009/unicode/boost/unicode/hangul.hpp 2009-08-07 23:06:01 EDT (Fri, 07 Aug 2009)
@@ -62,7 +62,7 @@
 };
 
 /** \c \xmlonly<conceptname>Pipe</conceptname>\endxmlonly that
- * transforms <L, V> and <LV, T> Hangul code points sequences into the
+ * transforms <L, V>, <L, V, T> and <LV, T> Hangul code points sequences into the
  * LV and LVT Hangul syllables, since those compositions are not part
  * of the UCD.
  * Other code points are left unchanged. */

Modified: sandbox/SOC/2009/unicode/boost/unicode/pipe_def.hpp
==============================================================================
--- sandbox/SOC/2009/unicode/boost/unicode/pipe_def.hpp (original)
+++ sandbox/SOC/2009/unicode/boost/unicode/pipe_def.hpp 2009-08-07 23:06:01 EDT (Fri, 07 Aug 2009)
@@ -140,6 +140,8 @@
 #endif
 
 /** Defines helper functions for usage of a \c \xmlonly<conceptname>OneManyPipe</conceptname>\endxmlonly.
+ * Helper functions provide a pseudo-variadic interface where they forward all the extra arguments to
+ * the constructor of the \c \xmlonly<conceptname>OneManyPipe</conceptname>\endxmlonly.
  * \arg \c name Name of the type modelling the \c \xmlonly<conceptname>OneManyPipe</conceptname>\endxmlonly.
  * \arg \c n Maximum number of optional arguments. */
 #define BOOST_UNICODE_ONE_MANY_PIPE_DEF(name, n) \
@@ -147,6 +149,8 @@
 BOOST_UNICODE_REPEAT(BOOST_PP_INC(n), BOOST_UNICODE_PIPE_OUTPUT_DEF, name)
 
 /** Defines helper functions for usage of a \c \xmlonly<conceptname>Pipe</conceptname>\endxmlonly.
+ * Helper functions provide a pseudo-variadic interface where they forward all the extra arguments to
+ * the constructor of the \c \xmlonly<conceptname>Pipe</conceptname>\endxmlonly.
  * \arg \c name Name of the type modelling the \c \xmlonly<conceptname>Pipe</conceptname>\endxmlonly.
  * \arg \c n Maximum number of optional arguments. */
 #define BOOST_UNICODE_PIPE_DEF(name, n) \

Modified: sandbox/SOC/2009/unicode/boost/unicode/ucd/properties.hpp
==============================================================================
--- sandbox/SOC/2009/unicode/boost/unicode/ucd/properties.hpp (original)
+++ sandbox/SOC/2009/unicode/boost/unicode/ucd/properties.hpp 2009-08-07 23:06:01 EDT (Fri, 07 Aug 2009)
@@ -10,6 +10,7 @@
 #include <boost/range.hpp>
 
 /** BOOST_UNICODE_UCD_VERSION / 1000 is the major version
+ *
  * BOOST_UNICODE_UCD_VERSION % 1000 is the minor version */
 #define BOOST_UNICODE_UCD_VERSION 5001
 #define BOOST_UNICODE_UCD_VERSION_MAJOR 5
@@ -73,13 +74,13 @@
  * \c block::none if the code point does not lie in any block. */
 BOOST_UNICODE_DECL block::type get_block(char32 ch);
 
-/** Returns the decomposition associated with \c ch as a zero-terminated
- * sequence of code points.
+/** Returns the decomposition associated with \c ch as a range of code
+ * points; an empty range is returned if there is none.
  * See the \c decomposition_type property to know what kind of decomposition it is. */
 inline iterator_range<const char32*> get_decomposition(char32 ch)
 {
     const char32* p = ucd::get_data_internal(ch).decomp;
- return make_iterator_range(p+1, p+1+p[0]);
+ return p ? make_iterator_range(p+1, p+1+p[0]) : make_iterator_range(p, p);
 }
 
 } // namespace ucd

Modified: sandbox/SOC/2009/unicode/boost/unicode/ucd/properties_types.hpp
==============================================================================
--- sandbox/SOC/2009/unicode/boost/unicode/ucd/properties_types.hpp (original)
+++ sandbox/SOC/2009/unicode/boost/unicode/ucd/properties_types.hpp 2009-08-07 23:06:01 EDT (Fri, 07 Aug 2009)
@@ -201,7 +201,7 @@
                                 vertical,
                                 wide,
                                 narrow,
- small,
+ small_,
                                 square,
                                 fraction,
                                 compat,

Modified: sandbox/SOC/2009/unicode/libs/unicode/data_parser/Jamfile.v2
==============================================================================
--- sandbox/SOC/2009/unicode/libs/unicode/data_parser/Jamfile.v2 (original)
+++ sandbox/SOC/2009/unicode/libs/unicode/data_parser/Jamfile.v2 2009-08-07 23:06:01 EDT (Fri, 07 Aug 2009)
@@ -8,8 +8,9 @@
 
 project
     : requirements
- <include>../../..
- <include>$(BOOST_ROOT)
+ <include>../../..
+ <include>$(BOOST_ROOT)
+ <define>BOOST_ALL_NO_LIB=1
     ;
 
 exe data_parser : main.cpp

Modified: sandbox/SOC/2009/unicode/libs/unicode/data_parser/read_character_properties_unicodedata.cpp
==============================================================================
--- sandbox/SOC/2009/unicode/libs/unicode/data_parser/read_character_properties_unicodedata.cpp (original)
+++ sandbox/SOC/2009/unicode/libs/unicode/data_parser/read_character_properties_unicodedata.cpp 2009-08-07 23:06:01 EDT (Fri, 07 Aug 2009)
@@ -257,7 +257,7 @@
                                 decomposition_type::narrow)] |
                 str_p ("<small>")
                         [assign_a (prop.decomposition_kind,
- decomposition_type::small)] |
+ decomposition_type::small_)] |
                 str_p ("<square>")
                         [assign_a (prop.decomposition_kind,
                                 decomposition_type::square)] |

Modified: sandbox/SOC/2009/unicode/libs/unicode/data_parser/write_character_properties.cpp
==============================================================================
--- sandbox/SOC/2009/unicode/libs/unicode/example/compose.cpp (original)
+++ sandbox/SOC/2009/unicode/libs/unicode/example/compose.cpp 2009-08-07 23:06:01 EDT (Fri, 07 Aug 2009)
@@ -1,4 +1,8 @@
 //[ compose
+/*`
+Example in development.
+*/
+
 #include <boost/unicode/compose.hpp>
 #include <boost/foreach.hpp>
 #include <boost/range/as_array.hpp>
@@ -56,8 +60,5 @@
     std::cout << "Canonical composition of { " << boost::as_array(bar) << " }: ";
     unicode::compose(bar, std::ostream_iterator<boost::char32>(std::cout, " "));
     std::cout << std::endl;
- std::cout << "Compatibility composition of { " << boost::as_array(bar) << " }: ";
- unicode::compose(bar, std::ostream_iterator<boost::char32>(std::cout, " "), UINT_MAX);
- std::cout << std::endl;
 }
 //]

Modified: sandbox/SOC/2009/unicode/libs/unicode/src/ucd/uni_ucd_interface_impl_compose_data.ipp
==============================================================================
--- sandbox/SOC/2009/unicode/libs/unicode/src/ucd/uni_ucd_interface_impl_compose_data.ipp (original)
+++ sandbox/SOC/2009/unicode/libs/unicode/src/ucd/uni_ucd_interface_impl_compose_data.ipp 2009-08-07 23:06:01 EDT (Fri, 07 Aug 2009)
@@ -22,311 +22,9 @@
 namespace boost { namespace unicode { namespace ucd {
 
 BOOST_UNICODE_DECL extern const unichar_compose_data_entry __uni_compose_entry[] = {
- {__uni_decomp_data_0xb4, 0xb4},
- {__uni_decomp_data_0x384, 0x384},
- {__uni_decomp_data_0x2dc, 0x2dc},
- {__uni_decomp_data_0xaf, 0xaf},
- {__uni_decomp_data_0x203e, 0x203e},
- {__uni_decomp_data_0x2d8, 0x2d8},
- {__uni_decomp_data_0x2d9, 0x2d9},
- {__uni_decomp_data_0xa8, 0xa8},
- {__uni_decomp_data_0x2da, 0x2da},
- {__uni_decomp_data_0x2dd, 0x2dd},
- {__uni_decomp_data_0x1fbf, 0x1fbf},
- {__uni_decomp_data_0x1fbd, 0x1fbd},
- {__uni_decomp_data_0x1ffe, 0x1ffe},
- {__uni_decomp_data_0xb8, 0xb8},
- {__uni_decomp_data_0x2db, 0x2db},
- {__uni_decomp_data_0x2017, 0x2017},
- {__uni_decomp_data_0x1fc0, 0x1fc0},
- {__uni_decomp_data_0x37a, 0x37a},
- {__uni_decomp_data_0xfe70, 0xfe70},
- {__uni_decomp_data_0xfe72, 0xfe72},
- {__uni_decomp_data_0xfc5e, 0xfc5e},
- {__uni_decomp_data_0xfe74, 0xfe74},
- {__uni_decomp_data_0xfc5f, 0xfc5f},
- {__uni_decomp_data_0xfe76, 0xfe76},
- {__uni_decomp_data_0xfc60, 0xfc60},
- {__uni_decomp_data_0xfe78, 0xfe78},
- {__uni_decomp_data_0xfc61, 0xfc61},
- {__uni_decomp_data_0xfe7a, 0xfe7a},
- {__uni_decomp_data_0xfc62, 0xfc62},
- {__uni_decomp_data_0xfe7c, 0xfe7c},
- {__uni_decomp_data_0xfc63, 0xfc63},
- {__uni_decomp_data_0xfe7e, 0xfe7e},
- {__uni_decomp_data_0x309b, 0x309b},
- {__uni_decomp_data_0x309c, 0x309c},
- {__uni_decomp_data_0x203c, 0x203c},
- {__uni_decomp_data_0x2049, 0x2049},
- {__uni_decomp_data_0x2474, 0x2474},
- {__uni_decomp_data_0x247d, 0x247d},
- {__uni_decomp_data_0x247e, 0x247e},
- {__uni_decomp_data_0x247f, 0x247f},
- {__uni_decomp_data_0x2480, 0x2480},
- {__uni_decomp_data_0x2481, 0x2481},
- {__uni_decomp_data_0x2482, 0x2482},
- {__uni_decomp_data_0x2483, 0x2483},
- {__uni_decomp_data_0x2484, 0x2484},
- {__uni_decomp_data_0x2485, 0x2485},
- {__uni_decomp_data_0x2486, 0x2486},
- {__uni_decomp_data_0x2475, 0x2475},
- {__uni_decomp_data_0x2487, 0x2487},
- {__uni_decomp_data_0x2476, 0x2476},
- {__uni_decomp_data_0x2477, 0x2477},
- {__uni_decomp_data_0x2478, 0x2478},
- {__uni_decomp_data_0x2479, 0x2479},
- {__uni_decomp_data_0x247a, 0x247a},
- {__uni_decomp_data_0x247b, 0x247b},
- {__uni_decomp_data_0x247c, 0x247c},
- {__uni_decomp_data_0x249c, 0x249c},
- {__uni_decomp_data_0x249d, 0x249d},
- {__uni_decomp_data_0x249e, 0x249e},
- {__uni_decomp_data_0x249f, 0x249f},
- {__uni_decomp_data_0x24a0, 0x24a0},
- {__uni_decomp_data_0x24a1, 0x24a1},
- {__uni_decomp_data_0x24a2, 0x24a2},
- {__uni_decomp_data_0x24a3, 0x24a3},
- {__uni_decomp_data_0x24a4, 0x24a4},
- {__uni_decomp_data_0x24a5, 0x24a5},
- {__uni_decomp_data_0x24a6, 0x24a6},
- {__uni_decomp_data_0x24a7, 0x24a7},
- {__uni_decomp_data_0x24a8, 0x24a8},
- {__uni_decomp_data_0x24a9, 0x24a9},
- {__uni_decomp_data_0x24aa, 0x24aa},
- {__uni_decomp_data_0x24ab, 0x24ab},
- {__uni_decomp_data_0x24ac, 0x24ac},
- {__uni_decomp_data_0x24ad, 0x24ad},
- {__uni_decomp_data_0x24ae, 0x24ae},
- {__uni_decomp_data_0x24af, 0x24af},
- {__uni_decomp_data_0x24b0, 0x24b0},
- {__uni_decomp_data_0x24b1, 0x24b1},
- {__uni_decomp_data_0x24b2, 0x24b2},
- {__uni_decomp_data_0x24b3, 0x24b3},
- {__uni_decomp_data_0x24b4, 0x24b4},
- {__uni_decomp_data_0x24b5, 0x24b5},
- {__uni_decomp_data_0x3200, 0x3200},
- {__uni_decomp_data_0x320e, 0x320e},
- {__uni_decomp_data_0x3201, 0x3201},
- {__uni_decomp_data_0x320f, 0x320f},
- {__uni_decomp_data_0x3202, 0x3202},
- {__uni_decomp_data_0x3210, 0x3210},
- {__uni_decomp_data_0x3203, 0x3203},
- {__uni_decomp_data_0x3211, 0x3211},
- {__uni_decomp_data_0x3204, 0x3204},
- {__uni_decomp_data_0x3212, 0x3212},
- {__uni_decomp_data_0x3205, 0x3205},
- {__uni_decomp_data_0x3213, 0x3213},
- {__uni_decomp_data_0x3206, 0x3206},
- {__uni_decomp_data_0x3214, 0x3214},
- {__uni_decomp_data_0x3207, 0x3207},
- {__uni_decomp_data_0x3215, 0x3215},
- {__uni_decomp_data_0x321d, 0x321d},
- {__uni_decomp_data_0x321e, 0x321e},
- {__uni_decomp_data_0x3208, 0x3208},
- {__uni_decomp_data_0x3216, 0x3216},
- {__uni_decomp_data_0x321c, 0x321c},
- {__uni_decomp_data_0x3209, 0x3209},
- {__uni_decomp_data_0x3217, 0x3217},
- {__uni_decomp_data_0x320a, 0x320a},
- {__uni_decomp_data_0x3218, 0x3218},
- {__uni_decomp_data_0x320b, 0x320b},
- {__uni_decomp_data_0x3219, 0x3219},
- {__uni_decomp_data_0x320c, 0x320c},
- {__uni_decomp_data_0x321a, 0x321a},
- {__uni_decomp_data_0x320d, 0x320d},
- {__uni_decomp_data_0x321b, 0x321b},
- {__uni_decomp_data_0x3220, 0x3220},
- {__uni_decomp_data_0x3226, 0x3226},
- {__uni_decomp_data_0x3222, 0x3222},
- {__uni_decomp_data_0x3228, 0x3228},
- {__uni_decomp_data_0x3221, 0x3221},
- {__uni_decomp_data_0x3224, 0x3224},
- {__uni_decomp_data_0x3239, 0x3239},
- {__uni_decomp_data_0x323d, 0x323d},
- {__uni_decomp_data_0x3241, 0x3241},
- {__uni_decomp_data_0x3227, 0x3227},
- {__uni_decomp_data_0x3225, 0x3225},
- {__uni_decomp_data_0x3238, 0x3238},
- {__uni_decomp_data_0x3229, 0x3229},
- {__uni_decomp_data_0x323f, 0x323f},
- {__uni_decomp_data_0x3234, 0x3234},
- {__uni_decomp_data_0x323a, 0x323a},
- {__uni_decomp_data_0x3223, 0x3223},
- {__uni_decomp_data_0x322f, 0x322f},
- {__uni_decomp_data_0x323b, 0x323b},
- {__uni_decomp_data_0x3230, 0x3230},
- {__uni_decomp_data_0x322a, 0x322a},
- {__uni_decomp_data_0x3232, 0x3232},
- {__uni_decomp_data_0x322d, 0x322d},
- {__uni_decomp_data_0x3231, 0x3231},
- {__uni_decomp_data_0x322c, 0x322c},
- {__uni_decomp_data_0x322b, 0x322b},
- {__uni_decomp_data_0x3235, 0x3235},
- {__uni_decomp_data_0x323c, 0x323c},
- {__uni_decomp_data_0x3233, 0x3233},
- {__uni_decomp_data_0x3237, 0x3237},
- {__uni_decomp_data_0x3240, 0x3240},
- {__uni_decomp_data_0x3242, 0x3242},
- {__uni_decomp_data_0x3243, 0x3243},
- {__uni_decomp_data_0x3236, 0x3236},
- {__uni_decomp_data_0x323e, 0x323e},
- {__uni_decomp_data_0x322e, 0x322e},
- {__uni_decomp_data_0x2025, 0x2025},
- {__uni_decomp_data_0x2026, 0x2026},
- {__uni_decomp_data_0x3358, 0x3358},
- {__uni_decomp_data_0x2488, 0x2488},
- {__uni_decomp_data_0x2469, 0x2469},
- {__uni_decomp_data_0x2491, 0x2491},
- {__uni_decomp_data_0x33e9, 0x33e9},
- {__uni_decomp_data_0x32c9, 0x32c9},
- {__uni_decomp_data_0x3362, 0x3362},
- {__uni_decomp_data_0x246a, 0x246a},
- {__uni_decomp_data_0x2492, 0x2492},
- {__uni_decomp_data_0x33ea, 0x33ea},
- {__uni_decomp_data_0x32ca, 0x32ca},
- {__uni_decomp_data_0x3363, 0x3363},
- {__uni_decomp_data_0x246b, 0x246b},
- {__uni_decomp_data_0x2493, 0x2493},
- {__uni_decomp_data_0x33eb, 0x33eb},
- {__uni_decomp_data_0x32cb, 0x32cb},
- {__uni_decomp_data_0x3364, 0x3364},
- {__uni_decomp_data_0x246c, 0x246c},
- {__uni_decomp_data_0x2494, 0x2494},
- {__uni_decomp_data_0x33ec, 0x33ec},
- {__uni_decomp_data_0x3365, 0x3365},
- {__uni_decomp_data_0x246d, 0x246d},
- {__uni_decomp_data_0x2495, 0x2495},
- {__uni_decomp_data_0x33ed, 0x33ed},
- {__uni_decomp_data_0x3366, 0x3366},
- {__uni_decomp_data_0x246e, 0x246e},
- {__uni_decomp_data_0x2496, 0x2496},
- {__uni_decomp_data_0x33ee, 0x33ee},
- {__uni_decomp_data_0x3367, 0x3367},
- {__uni_decomp_data_0x246f, 0x246f},
- {__uni_decomp_data_0x2497, 0x2497},
- {__uni_decomp_data_0x33ef, 0x33ef},
- {__uni_decomp_data_0x3368, 0x3368},
- {__uni_decomp_data_0x2470, 0x2470},
- {__uni_decomp_data_0x2498, 0x2498},
- {__uni_decomp_data_0x33f0, 0x33f0},
- {__uni_decomp_data_0x3369, 0x3369},
- {__uni_decomp_data_0x2471, 0x2471},
- {__uni_decomp_data_0x2499, 0x2499},
- {__uni_decomp_data_0x33f1, 0x33f1},
- {__uni_decomp_data_0x336a, 0x336a},
- {__uni_decomp_data_0x2472, 0x2472},
- {__uni_decomp_data_0x249a, 0x249a},
- {__uni_decomp_data_0x33f2, 0x33f2},
- {__uni_decomp_data_0x336b, 0x336b},
- {__uni_decomp_data_0x215f, 0x215f},
- {__uni_decomp_data_0xbd, 0xbd},
- {__uni_decomp_data_0x2153, 0x2153},
- {__uni_decomp_data_0xbc, 0xbc},
- {__uni_decomp_data_0x2155, 0x2155},
- {__uni_decomp_data_0x2159, 0x2159},
- {__uni_decomp_data_0x215b, 0x215b},
- {__uni_decomp_data_0x33e0, 0x33e0},
- {__uni_decomp_data_0x32c0, 0x32c0},
- {__uni_decomp_data_0x3359, 0x3359},
- {__uni_decomp_data_0x2489, 0x2489},
- {__uni_decomp_data_0x2473, 0x2473},
- {__uni_decomp_data_0x249b, 0x249b},
- {__uni_decomp_data_0x33f3, 0x33f3},
- {__uni_decomp_data_0x336c, 0x336c},
- {__uni_decomp_data_0x3251, 0x3251},
- {__uni_decomp_data_0x33f4, 0x33f4},
- {__uni_decomp_data_0x336d, 0x336d},
- {__uni_decomp_data_0x3252, 0x3252},
- {__uni_decomp_data_0x33f5, 0x33f5},
- {__uni_decomp_data_0x336e, 0x336e},
- {__uni_decomp_data_0x3253, 0x3253},
- {__uni_decomp_data_0x33f6, 0x33f6},
- {__uni_decomp_data_0x336f, 0x336f},
- {__uni_decomp_data_0x3254, 0x3254},
- {__uni_decomp_data_0x33f7, 0x33f7},
- {__uni_decomp_data_0x3370, 0x3370},
- {__uni_decomp_data_0x3255, 0x3255},
- {__uni_decomp_data_0x33f8, 0x33f8},
- {__uni_decomp_data_0x3256, 0x3256},
- {__uni_decomp_data_0x33f9, 0x33f9},
- {__uni_decomp_data_0x3257, 0x3257},
- {__uni_decomp_data_0x33fa, 0x33fa},
- {__uni_decomp_data_0x3258, 0x3258},
- {__uni_decomp_data_0x33fb, 0x33fb},
- {__uni_decomp_data_0x3259, 0x3259},
- {__uni_decomp_data_0x33fc, 0x33fc},
- {__uni_decomp_data_0x2154, 0x2154},
- {__uni_decomp_data_0x2156, 0x2156},
- {__uni_decomp_data_0x33e1, 0x33e1},
- {__uni_decomp_data_0x32c1, 0x32c1},
- {__uni_decomp_data_0x335a, 0x335a},
- {__uni_decomp_data_0x248a, 0x248a},
- {__uni_decomp_data_0x325a, 0x325a},
- {__uni_decomp_data_0x33fd, 0x33fd},
- {__uni_decomp_data_0x325b, 0x325b},
- {__uni_decomp_data_0x33fe, 0x33fe},
- {__uni_decomp_data_0x325c, 0x325c},
- {__uni_decomp_data_0x325d, 0x325d},
- {__uni_decomp_data_0x325e, 0x325e},
- {__uni_decomp_data_0x325f, 0x325f},
- {__uni_decomp_data_0x32b1, 0x32b1},
- {__uni_decomp_data_0x32b2, 0x32b2},
- {__uni_decomp_data_0x32b3, 0x32b3},
- {__uni_decomp_data_0x32b4, 0x32b4},
- {__uni_decomp_data_0xbe, 0xbe},
- {__uni_decomp_data_0x2157, 0x2157},
- {__uni_decomp_data_0x215c, 0x215c},
- {__uni_decomp_data_0x33e2, 0x33e2},
- {__uni_decomp_data_0x32c2, 0x32c2},
- {__uni_decomp_data_0x335b, 0x335b},
- {__uni_decomp_data_0x248b, 0x248b},
- {__uni_decomp_data_0x32b5, 0x32b5},
- {__uni_decomp_data_0x32b6, 0x32b6},
- {__uni_decomp_data_0x32b7, 0x32b7},
- {__uni_decomp_data_0x32b8, 0x32b8},
- {__uni_decomp_data_0x32b9, 0x32b9},
- {__uni_decomp_data_0x32ba, 0x32ba},
- {__uni_decomp_data_0x32bb, 0x32bb},
- {__uni_decomp_data_0x32bc, 0x32bc},
- {__uni_decomp_data_0x32bd, 0x32bd},
- {__uni_decomp_data_0x32be, 0x32be},
- {__uni_decomp_data_0x2158, 0x2158},
- {__uni_decomp_data_0x33e3, 0x33e3},
- {__uni_decomp_data_0x32c3, 0x32c3},
- {__uni_decomp_data_0x335c, 0x335c},
- {__uni_decomp_data_0x248c, 0x248c},
- {__uni_decomp_data_0x32bf, 0x32bf},
- {__uni_decomp_data_0x215a, 0x215a},
- {__uni_decomp_data_0x215d, 0x215d},
- {__uni_decomp_data_0x33e4, 0x33e4},
- {__uni_decomp_data_0x32c4, 0x32c4},
- {__uni_decomp_data_0x335d, 0x335d},
- {__uni_decomp_data_0x248d, 0x248d},
- {__uni_decomp_data_0x33e5, 0x33e5},
- {__uni_decomp_data_0x32c5, 0x32c5},
- {__uni_decomp_data_0x335e, 0x335e},
- {__uni_decomp_data_0x248e, 0x248e},
- {__uni_decomp_data_0x215e, 0x215e},
- {__uni_decomp_data_0x33e6, 0x33e6},
- {__uni_decomp_data_0x32c6, 0x32c6},
- {__uni_decomp_data_0x335f, 0x335f},
- {__uni_decomp_data_0x248f, 0x248f},
- {__uni_decomp_data_0x33e7, 0x33e7},
- {__uni_decomp_data_0x32c7, 0x32c7},
- {__uni_decomp_data_0x3360, 0x3360},
- {__uni_decomp_data_0x2490, 0x2490},
- {__uni_decomp_data_0x33e8, 0x33e8},
- {__uni_decomp_data_0x32c8, 0x32c8},
- {__uni_decomp_data_0x3361, 0x3361},
- {__uni_decomp_data_0x2a74, 0x2a74},
         {__uni_decomp_data_0x226e, 0x226e},
- {__uni_decomp_data_0x2a75, 0x2a75},
- {__uni_decomp_data_0x2a76, 0x2a76},
         {__uni_decomp_data_0x2260, 0x2260},
         {__uni_decomp_data_0x226f, 0x226f},
- {__uni_decomp_data_0x2048, 0x2048},
- {__uni_decomp_data_0x2047, 0x2047},
- {__uni_decomp_data_0x3373, 0x3373},
         {__uni_decomp_data_0xc0, 0xc0},
         {__uni_decomp_data_0xc1, 0xc1},
         {__uni_decomp_data_0xc2, 0xc2},
@@ -343,22 +41,14 @@
         {__uni_decomp_data_0x1ea0, 0x1ea0},
         {__uni_decomp_data_0x1e00, 0x1e00},
         {__uni_decomp_data_0x104, 0x104},
- {__uni_decomp_data_0x33df, 0x33df},
- {__uni_decomp_data_0x33c3, 0x33c3},
         {__uni_decomp_data_0x1e02, 0x1e02},
         {__uni_decomp_data_0x1e04, 0x1e04},
         {__uni_decomp_data_0x1e06, 0x1e06},
- {__uni_decomp_data_0x33c7, 0x33c7},
         {__uni_decomp_data_0x106, 0x106},
         {__uni_decomp_data_0x108, 0x108},
         {__uni_decomp_data_0x10a, 0x10a},
         {__uni_decomp_data_0x10c, 0x10c},
         {__uni_decomp_data_0xc7, 0xc7},
- {__uni_decomp_data_0x33c6, 0x33c6},
- {__uni_decomp_data_0x1f1, 0x1f1},
- {__uni_decomp_data_0x1f2, 0x1f2},
- {__uni_decomp_data_0x1c4, 0x1c4},
- {__uni_decomp_data_0x1c5, 0x1c5},
         {__uni_decomp_data_0x1e0a, 0x1e0a},
         {__uni_decomp_data_0x10e, 0x10e},
         {__uni_decomp_data_0x1e0c, 0x1e0c},
@@ -382,12 +72,7 @@
         {__uni_decomp_data_0x118, 0x118},
         {__uni_decomp_data_0x1e18, 0x1e18},
         {__uni_decomp_data_0x1e1a, 0x1e1a},
- {__uni_decomp_data_0x213b, 0x213b},
         {__uni_decomp_data_0x1e1e, 0x1e1e},
- {__uni_decomp_data_0x3387, 0x3387},
- {__uni_decomp_data_0x3393, 0x3393},
- {__uni_decomp_data_0x33ac, 0x33ac},
- {__uni_decomp_data_0x33c9, 0x33c9},
         {__uni_decomp_data_0x1f4, 0x1f4},
         {__uni_decomp_data_0x11c, 0x11c},
         {__uni_decomp_data_0x1e20, 0x1e20},
@@ -395,9 +80,6 @@
         {__uni_decomp_data_0x120, 0x120},
         {__uni_decomp_data_0x1e6, 0x1e6},
         {__uni_decomp_data_0x122, 0x122},
- {__uni_decomp_data_0x33cb, 0x33cb},
- {__uni_decomp_data_0x32cc, 0x32cc},
- {__uni_decomp_data_0x3390, 0x3390},
         {__uni_decomp_data_0x124, 0x124},
         {__uni_decomp_data_0x1e22, 0x1e22},
         {__uni_decomp_data_0x1e26, 0x1e26},
@@ -405,12 +87,6 @@
         {__uni_decomp_data_0x1e24, 0x1e24},
         {__uni_decomp_data_0x1e28, 0x1e28},
         {__uni_decomp_data_0x1e2a, 0x1e2a},
- {__uni_decomp_data_0x2161, 0x2161},
- {__uni_decomp_data_0x2162, 0x2162},
- {__uni_decomp_data_0x132, 0x132},
- {__uni_decomp_data_0x337a, 0x337a},
- {__uni_decomp_data_0x2163, 0x2163},
- {__uni_decomp_data_0x2168, 0x2168},
         {__uni_decomp_data_0xcc, 0xcc},
         {__uni_decomp_data_0xcd, 0xcd},
         {__uni_decomp_data_0xce, 0xce},
@@ -427,36 +103,20 @@
         {__uni_decomp_data_0x12e, 0x12e},
         {__uni_decomp_data_0x1e2c, 0x1e2c},
         {__uni_decomp_data_0x134, 0x134},
- {__uni_decomp_data_0x3385, 0x3385},
- {__uni_decomp_data_0x33cd, 0x33cd},
- {__uni_decomp_data_0x33ce, 0x33ce},
         {__uni_decomp_data_0x1e30, 0x1e30},
         {__uni_decomp_data_0x1e8, 0x1e8},
         {__uni_decomp_data_0x1e32, 0x1e32},
         {__uni_decomp_data_0x136, 0x136},
         {__uni_decomp_data_0x1e34, 0x1e34},
- {__uni_decomp_data_0x1c7, 0x1c7},
- {__uni_decomp_data_0x32cf, 0x32cf},
- {__uni_decomp_data_0x1c8, 0x1c8},
- {__uni_decomp_data_0x13f, 0x13f},
         {__uni_decomp_data_0x139, 0x139},
         {__uni_decomp_data_0x13d, 0x13d},
         {__uni_decomp_data_0x1e36, 0x1e36},
         {__uni_decomp_data_0x13b, 0x13b},
         {__uni_decomp_data_0x1e3c, 0x1e3c},
         {__uni_decomp_data_0x1e3a, 0x1e3a},
- {__uni_decomp_data_0x3386, 0x3386},
- {__uni_decomp_data_0x3392, 0x3392},
- {__uni_decomp_data_0x33ab, 0x33ab},
- {__uni_decomp_data_0x33b9, 0x33b9},
- {__uni_decomp_data_0x33bf, 0x33bf},
         {__uni_decomp_data_0x1e3e, 0x1e3e},
         {__uni_decomp_data_0x1e40, 0x1e40},
         {__uni_decomp_data_0x1e42, 0x1e42},
- {__uni_decomp_data_0x33c1, 0x33c1},
- {__uni_decomp_data_0x1ca, 0x1ca},
- {__uni_decomp_data_0x1cb, 0x1cb},
- {__uni_decomp_data_0x2116, 0x2116},
         {__uni_decomp_data_0x1f8, 0x1f8},
         {__uni_decomp_data_0x143, 0x143},
         {__uni_decomp_data_0xd1, 0xd1},
@@ -482,14 +142,8 @@
         {__uni_decomp_data_0x1a0, 0x1a0},
         {__uni_decomp_data_0x1ecc, 0x1ecc},
         {__uni_decomp_data_0x1ea, 0x1ea},
- {__uni_decomp_data_0x33d7, 0x33d7},
- {__uni_decomp_data_0x33d9, 0x33d9},
- {__uni_decomp_data_0x33da, 0x33da},
- {__uni_decomp_data_0x3250, 0x3250},
- {__uni_decomp_data_0x33a9, 0x33a9},
         {__uni_decomp_data_0x1e54, 0x1e54},
         {__uni_decomp_data_0x1e56, 0x1e56},
- {__uni_decomp_data_0x20a8, 0x20a8},
         {__uni_decomp_data_0x154, 0x154},
         {__uni_decomp_data_0x1e58, 0x1e58},
         {__uni_decomp_data_0x158, 0x158},
@@ -498,8 +152,6 @@
         {__uni_decomp_data_0x1e5a, 0x1e5a},
         {__uni_decomp_data_0x156, 0x156},
         {__uni_decomp_data_0x1e5e, 0x1e5e},
- {__uni_decomp_data_0x2120, 0x2120},
- {__uni_decomp_data_0x33dc, 0x33dc},
         {__uni_decomp_data_0x15a, 0x15a},
         {__uni_decomp_data_0x15c, 0x15c},
         {__uni_decomp_data_0x1e60, 0x1e60},
@@ -507,9 +159,6 @@
         {__uni_decomp_data_0x1e62, 0x1e62},
         {__uni_decomp_data_0x218, 0x218},
         {__uni_decomp_data_0x15e, 0x15e},
- {__uni_decomp_data_0x2121, 0x2121},
- {__uni_decomp_data_0x3394, 0x3394},
- {__uni_decomp_data_0x2122, 0x2122},
         {__uni_decomp_data_0x1e6a, 0x1e6a},
         {__uni_decomp_data_0x164, 0x164},
         {__uni_decomp_data_0x1e6c, 0x1e6c},
@@ -536,21 +185,14 @@
         {__uni_decomp_data_0x172, 0x172},
         {__uni_decomp_data_0x1e76, 0x1e76},
         {__uni_decomp_data_0x1e74, 0x1e74},
- {__uni_decomp_data_0x2165, 0x2165},
- {__uni_decomp_data_0x2166, 0x2166},
- {__uni_decomp_data_0x2167, 0x2167},
         {__uni_decomp_data_0x1e7c, 0x1e7c},
         {__uni_decomp_data_0x1e7e, 0x1e7e},
- {__uni_decomp_data_0x33de, 0x33de},
- {__uni_decomp_data_0x33dd, 0x33dd},
         {__uni_decomp_data_0x1e80, 0x1e80},
         {__uni_decomp_data_0x1e82, 0x1e82},
         {__uni_decomp_data_0x174, 0x174},
         {__uni_decomp_data_0x1e86, 0x1e86},
         {__uni_decomp_data_0x1e84, 0x1e84},
         {__uni_decomp_data_0x1e88, 0x1e88},
- {__uni_decomp_data_0x216a, 0x216a},
- {__uni_decomp_data_0x216b, 0x216b},
         {__uni_decomp_data_0x1e8a, 0x1e8a},
         {__uni_decomp_data_0x1e8c, 0x1e8c},
         {__uni_decomp_data_0x1ef2, 0x1ef2},
@@ -568,10 +210,6 @@
         {__uni_decomp_data_0x17d, 0x17d},
         {__uni_decomp_data_0x1e92, 0x1e92},
         {__uni_decomp_data_0x1e94, 0x1e94},
- {__uni_decomp_data_0x33c2, 0x33c2},
- {__uni_decomp_data_0x2100, 0x2100},
- {__uni_decomp_data_0x2101, 0x2101},
- {__uni_decomp_data_0x1e9a, 0x1e9a},
         {__uni_decomp_data_0xe0, 0xe0},
         {__uni_decomp_data_0xe1, 0xe1},
         {__uni_decomp_data_0xe2, 0xe2},
@@ -588,39 +226,20 @@
         {__uni_decomp_data_0x1ea1, 0x1ea1},
         {__uni_decomp_data_0x1e01, 0x1e01},
         {__uni_decomp_data_0x105, 0x105},
- {__uni_decomp_data_0x3374, 0x3374},
         {__uni_decomp_data_0x1e03, 0x1e03},
         {__uni_decomp_data_0x1e05, 0x1e05},
         {__uni_decomp_data_0x1e07, 0x1e07},
- {__uni_decomp_data_0x2105, 0x2105},
- {__uni_decomp_data_0x2106, 0x2106},
- {__uni_decomp_data_0x3388, 0x3388},
- {__uni_decomp_data_0x33c4, 0x33c4},
- {__uni_decomp_data_0x33c5, 0x33c5},
- {__uni_decomp_data_0x339d, 0x339d},
- {__uni_decomp_data_0x33a0, 0x33a0},
- {__uni_decomp_data_0x33a4, 0x33a4},
         {__uni_decomp_data_0x107, 0x107},
         {__uni_decomp_data_0x109, 0x109},
         {__uni_decomp_data_0x10b, 0x10b},
         {__uni_decomp_data_0x10d, 0x10d},
         {__uni_decomp_data_0xe7, 0xe7},
- {__uni_decomp_data_0x33c8, 0x33c8},
- {__uni_decomp_data_0x3372, 0x3372},
- {__uni_decomp_data_0x3377, 0x3377},
- {__uni_decomp_data_0x3378, 0x3378},
- {__uni_decomp_data_0x3379, 0x3379},
- {__uni_decomp_data_0x1f3, 0x1f3},
- {__uni_decomp_data_0x1c6, 0x1c6},
         {__uni_decomp_data_0x1e0b, 0x1e0b},
         {__uni_decomp_data_0x10f, 0x10f},
         {__uni_decomp_data_0x1e0d, 0x1e0d},
         {__uni_decomp_data_0x1e11, 0x1e11},
         {__uni_decomp_data_0x1e13, 0x1e13},
         {__uni_decomp_data_0x1e0f, 0x1e0f},
- {__uni_decomp_data_0x3397, 0x3397},
- {__uni_decomp_data_0x32ce, 0x32ce},
- {__uni_decomp_data_0x32cd, 0x32cd},
         {__uni_decomp_data_0xe8, 0xe8},
         {__uni_decomp_data_0xe9, 0xe9},
         {__uni_decomp_data_0xea, 0xea},
@@ -638,14 +257,7 @@
         {__uni_decomp_data_0x119, 0x119},
         {__uni_decomp_data_0x1e19, 0x1e19},
         {__uni_decomp_data_0x1e1b, 0x1e1b},
- {__uni_decomp_data_0xfb00, 0xfb00},
- {__uni_decomp_data_0xfb03, 0xfb03},
- {__uni_decomp_data_0xfb04, 0xfb04},
- {__uni_decomp_data_0xfb01, 0xfb01},
- {__uni_decomp_data_0xfb02, 0xfb02},
- {__uni_decomp_data_0x3399, 0x3399},
         {__uni_decomp_data_0x1e1f, 0x1e1f},
- {__uni_decomp_data_0x33ff, 0x33ff},
         {__uni_decomp_data_0x1f5, 0x1f5},
         {__uni_decomp_data_0x11d, 0x11d},
         {__uni_decomp_data_0x1e21, 0x1e21},
@@ -653,8 +265,6 @@
         {__uni_decomp_data_0x121, 0x121},
         {__uni_decomp_data_0x1e7, 0x1e7},
         {__uni_decomp_data_0x123, 0x123},
- {__uni_decomp_data_0x3371, 0x3371},
- {__uni_decomp_data_0x33ca, 0x33ca},
         {__uni_decomp_data_0x125, 0x125},
         {__uni_decomp_data_0x1e23, 0x1e23},
         {__uni_decomp_data_0x1e27, 0x1e27},
@@ -663,12 +273,6 @@
         {__uni_decomp_data_0x1e29, 0x1e29},
         {__uni_decomp_data_0x1e2b, 0x1e2b},
         {__uni_decomp_data_0x1e96, 0x1e96},
- {__uni_decomp_data_0x2171, 0x2171},
- {__uni_decomp_data_0x2172, 0x2172},
- {__uni_decomp_data_0x133, 0x133},
- {__uni_decomp_data_0x33cc, 0x33cc},
- {__uni_decomp_data_0x2173, 0x2173},
- {__uni_decomp_data_0x2178, 0x2178},
         {__uni_decomp_data_0xec, 0xec},
         {__uni_decomp_data_0xed, 0xed},
         {__uni_decomp_data_0xee, 0xee},
@@ -685,62 +289,20 @@
         {__uni_decomp_data_0x1e2d, 0x1e2d},
         {__uni_decomp_data_0x135, 0x135},
         {__uni_decomp_data_0x1f0, 0x1f0},
- {__uni_decomp_data_0x3384, 0x3384},
- {__uni_decomp_data_0x3391, 0x3391},
- {__uni_decomp_data_0x33aa, 0x33aa},
- {__uni_decomp_data_0x33b8, 0x33b8},
- {__uni_decomp_data_0x33be, 0x33be},
- {__uni_decomp_data_0x3389, 0x3389},
- {__uni_decomp_data_0x338f, 0x338f},
- {__uni_decomp_data_0x339e, 0x339e},
- {__uni_decomp_data_0x33a2, 0x33a2},
- {__uni_decomp_data_0x33a6, 0x33a6},
- {__uni_decomp_data_0x33cf, 0x33cf},
         {__uni_decomp_data_0x1e31, 0x1e31},
         {__uni_decomp_data_0x1e9, 0x1e9},
         {__uni_decomp_data_0x1e33, 0x1e33},
         {__uni_decomp_data_0x137, 0x137},
         {__uni_decomp_data_0x1e35, 0x1e35},
- {__uni_decomp_data_0x33c0, 0x33c0},
- {__uni_decomp_data_0x3398, 0x3398},
- {__uni_decomp_data_0x1c9, 0x1c9},
- {__uni_decomp_data_0x33d0, 0x33d0},
- {__uni_decomp_data_0x33d1, 0x33d1},
- {__uni_decomp_data_0x33d2, 0x33d2},
- {__uni_decomp_data_0x33d3, 0x33d3},
- {__uni_decomp_data_0x140, 0x140},
         {__uni_decomp_data_0x13a, 0x13a},
         {__uni_decomp_data_0x13e, 0x13e},
         {__uni_decomp_data_0x1e37, 0x1e37},
         {__uni_decomp_data_0x13c, 0x13c},
         {__uni_decomp_data_0x1e3d, 0x1e3d},
         {__uni_decomp_data_0x1e3b, 0x1e3b},
- {__uni_decomp_data_0x3383, 0x3383},
- {__uni_decomp_data_0x33b7, 0x33b7},
- {__uni_decomp_data_0x33bd, 0x33bd},
- {__uni_decomp_data_0x33d4, 0x33d4},
- {__uni_decomp_data_0x338e, 0x338e},
- {__uni_decomp_data_0x33d5, 0x33d5},
- {__uni_decomp_data_0x339c, 0x339c},
- {__uni_decomp_data_0x339f, 0x339f},
- {__uni_decomp_data_0x33a3, 0x33a3},
- {__uni_decomp_data_0x33d6, 0x33d6},
- {__uni_decomp_data_0x33b3, 0x33b3},
- {__uni_decomp_data_0x33a1, 0x33a1},
- {__uni_decomp_data_0x33a5, 0x33a5},
         {__uni_decomp_data_0x1e3f, 0x1e3f},
         {__uni_decomp_data_0x1e41, 0x1e41},
         {__uni_decomp_data_0x1e43, 0x1e43},
- {__uni_decomp_data_0x3396, 0x3396},
- {__uni_decomp_data_0x33a7, 0x33a7},
- {__uni_decomp_data_0x33a8, 0x33a8},
- {__uni_decomp_data_0x3381, 0x3381},
- {__uni_decomp_data_0x338b, 0x338b},
- {__uni_decomp_data_0x33b5, 0x33b5},
- {__uni_decomp_data_0x33bb, 0x33bb},
- {__uni_decomp_data_0x1cc, 0x1cc},
- {__uni_decomp_data_0x339a, 0x339a},
- {__uni_decomp_data_0x33b1, 0x33b1},
         {__uni_decomp_data_0x1f9, 0x1f9},
         {__uni_decomp_data_0x144, 0x144},
         {__uni_decomp_data_0xf1, 0xf1},
@@ -750,7 +312,6 @@
         {__uni_decomp_data_0x146, 0x146},
         {__uni_decomp_data_0x1e4b, 0x1e4b},
         {__uni_decomp_data_0x1e49, 0x1e49},
- {__uni_decomp_data_0x3375, 0x3375},
         {__uni_decomp_data_0xf2, 0xf2},
         {__uni_decomp_data_0xf3, 0xf3},
         {__uni_decomp_data_0xf4, 0xf4},
@@ -767,18 +328,8 @@
         {__uni_decomp_data_0x1a1, 0x1a1},
         {__uni_decomp_data_0x1ecd, 0x1ecd},
         {__uni_decomp_data_0x1eb, 0x1eb},
- {__uni_decomp_data_0x33d8, 0x33d8},
- {__uni_decomp_data_0x3380, 0x3380},
- {__uni_decomp_data_0x338a, 0x338a},
- {__uni_decomp_data_0x33b4, 0x33b4},
- {__uni_decomp_data_0x33ba, 0x33ba},
- {__uni_decomp_data_0x3376, 0x3376},
- {__uni_decomp_data_0x33b0, 0x33b0},
         {__uni_decomp_data_0x1e55, 0x1e55},
         {__uni_decomp_data_0x1e57, 0x1e57},
- {__uni_decomp_data_0x33ad, 0x33ad},
- {__uni_decomp_data_0x33ae, 0x33ae},
- {__uni_decomp_data_0x33af, 0x33af},
         {__uni_decomp_data_0x155, 0x155},
         {__uni_decomp_data_0x1e59, 0x1e59},
         {__uni_decomp_data_0x159, 0x159},
@@ -787,8 +338,6 @@
         {__uni_decomp_data_0x1e5b, 0x1e5b},
         {__uni_decomp_data_0x157, 0x157},
         {__uni_decomp_data_0x1e5f, 0x1e5f},
- {__uni_decomp_data_0x33db, 0x33db},
- {__uni_decomp_data_0xfb06, 0xfb06},
         {__uni_decomp_data_0x15b, 0x15b},
         {__uni_decomp_data_0x15d, 0x15d},
         {__uni_decomp_data_0x1e61, 0x1e61},
@@ -823,9 +372,6 @@
         {__uni_decomp_data_0x173, 0x173},
         {__uni_decomp_data_0x1e77, 0x1e77},
         {__uni_decomp_data_0x1e75, 0x1e75},
- {__uni_decomp_data_0x2175, 0x2175},
- {__uni_decomp_data_0x2176, 0x2176},
- {__uni_decomp_data_0x2177, 0x2177},
         {__uni_decomp_data_0x1e7d, 0x1e7d},
         {__uni_decomp_data_0x1e7f, 0x1e7f},
         {__uni_decomp_data_0x1e81, 0x1e81},
@@ -835,8 +381,6 @@
         {__uni_decomp_data_0x1e85, 0x1e85},
         {__uni_decomp_data_0x1e98, 0x1e98},
         {__uni_decomp_data_0x1e89, 0x1e89},
- {__uni_decomp_data_0x217a, 0x217a},
- {__uni_decomp_data_0x217b, 0x217b},
         {__uni_decomp_data_0x1e8b, 0x1e8b},
         {__uni_decomp_data_0x1e8d, 0x1e8d},
         {__uni_decomp_data_0x1ef3, 0x1ef3},
@@ -858,8 +402,6 @@
         {__uni_decomp_data_0x1fed, 0x1fed},
         {__uni_decomp_data_0x385, 0x385},
         {__uni_decomp_data_0x1fc1, 0x1fc1},
- {__uni_decomp_data_0x2103, 0x2103},
- {__uni_decomp_data_0x2109, 0x2109},
         {__uni_decomp_data_0x1ea6, 0x1ea6},
         {__uni_decomp_data_0x1ea4, 0x1ea4},
         {__uni_decomp_data_0x1eaa, 0x1eaa},
@@ -938,7 +480,6 @@
         {__uni_decomp_data_0x1e79, 0x1e79},
         {__uni_decomp_data_0x1e7a, 0x1e7a},
         {__uni_decomp_data_0x1e7b, 0x1e7b},
- {__uni_decomp_data_0xfb05, 0xfb05},
         {__uni_decomp_data_0x1e9b, 0x1e9b},
         {__uni_decomp_data_0x1edc, 0x1edc},
         {__uni_decomp_data_0x1eda, 0x1eda},
@@ -970,7 +511,6 @@
         {__uni_decomp_data_0x230, 0x230},
         {__uni_decomp_data_0x231, 0x231},
         {__uni_decomp_data_0x1ef, 0x1ef},
- {__uni_decomp_data_0x149, 0x149},
         {__uni_decomp_data_0x1fba, 0x1fba},
         {__uni_decomp_data_0x386, 0x386},
         {__uni_decomp_data_0x1fb9, 0x1fb9},
@@ -1038,14 +578,6 @@
         {__uni_decomp_data_0x1f30, 0x1f30},
         {__uni_decomp_data_0x1f31, 0x1f31},
         {__uni_decomp_data_0x1fd6, 0x1fd6},
- {__uni_decomp_data_0x3382, 0x3382},
- {__uni_decomp_data_0x338c, 0x338c},
- {__uni_decomp_data_0x33b6, 0x33b6},
- {__uni_decomp_data_0x33bc, 0x33bc},
- {__uni_decomp_data_0x338d, 0x338d},
- {__uni_decomp_data_0x339b, 0x339b},
- {__uni_decomp_data_0x33b2, 0x33b2},
- {__uni_decomp_data_0x3395, 0x3395},
         {__uni_decomp_data_0x1f78, 0x1f78},
         {__uni_decomp_data_0x3cc, 0x3cc},
         {__uni_decomp_data_0x1f40, 0x1f40},
@@ -1127,498 +659,12 @@
         {__uni_decomp_data_0x4db, 0x4db},
         {__uni_decomp_data_0x4ea, 0x4ea},
         {__uni_decomp_data_0x4eb, 0x4eb},
- {__uni_decomp_data_0x587, 0x587},
- {__uni_decomp_data_0xfb14, 0xfb14},
- {__uni_decomp_data_0xfb15, 0xfb15},
- {__uni_decomp_data_0xfb17, 0xfb17},
- {__uni_decomp_data_0xfb13, 0xfb13},
- {__uni_decomp_data_0xfb16, 0xfb16},
- {__uni_decomp_data_0xfb4f, 0xfb4f},
- {__uni_decomp_data_0xfbea, 0xfbea},
- {__uni_decomp_data_0xfbeb, 0xfbeb},
- {__uni_decomp_data_0xfc00, 0xfc00},
- {__uni_decomp_data_0xfc97, 0xfc97},
- {__uni_decomp_data_0xfc98, 0xfc98},
- {__uni_decomp_data_0xfc01, 0xfc01},
- {__uni_decomp_data_0xfc99, 0xfc99},
- {__uni_decomp_data_0xfc64, 0xfc64},
- {__uni_decomp_data_0xfc65, 0xfc65},
- {__uni_decomp_data_0xfc66, 0xfc66},
- {__uni_decomp_data_0xfc02, 0xfc02},
- {__uni_decomp_data_0xfcdf, 0xfcdf},
- {__uni_decomp_data_0xfc9a, 0xfc9a},
- {__uni_decomp_data_0xfc67, 0xfc67},
- {__uni_decomp_data_0xfce0, 0xfce0},
- {__uni_decomp_data_0xfc9b, 0xfc9b},
- {__uni_decomp_data_0xfbef, 0xfbef},
- {__uni_decomp_data_0xfbee, 0xfbee},
- {__uni_decomp_data_0xfbf9, 0xfbf9},
- {__uni_decomp_data_0xfbfa, 0xfbfa},
- {__uni_decomp_data_0xfbfb, 0xfbfb},
- {__uni_decomp_data_0xfc03, 0xfc03},
- {__uni_decomp_data_0xfc68, 0xfc68},
- {__uni_decomp_data_0xfc04, 0xfc04},
- {__uni_decomp_data_0xfc69, 0xfc69},
- {__uni_decomp_data_0xfbf2, 0xfbf2},
- {__uni_decomp_data_0xfbf3, 0xfbf3},
- {__uni_decomp_data_0xfbf0, 0xfbf0},
- {__uni_decomp_data_0xfbf1, 0xfbf1},
- {__uni_decomp_data_0xfbf4, 0xfbf4},
- {__uni_decomp_data_0xfbf5, 0xfbf5},
- {__uni_decomp_data_0xfbf8, 0xfbf8},
- {__uni_decomp_data_0xfbf6, 0xfbf6},
- {__uni_decomp_data_0xfbf7, 0xfbf7},
- {__uni_decomp_data_0xfbed, 0xfbed},
- {__uni_decomp_data_0xfbec, 0xfbec},
- {__uni_decomp_data_0xfdf3, 0xfdf3},
- {__uni_decomp_data_0xfdf2, 0xfdf2},
- {__uni_decomp_data_0xfd3c, 0xfd3c},
- {__uni_decomp_data_0xfd3d, 0xfd3d},
         {__uni_decomp_data_0x622, 0x622},
         {__uni_decomp_data_0x623, 0x623},
         {__uni_decomp_data_0x625, 0x625},
- {__uni_decomp_data_0x675, 0x675},
- {__uni_decomp_data_0xfc9c, 0xfc9c},
- {__uni_decomp_data_0xfc05, 0xfc05},
- {__uni_decomp_data_0xfc9d, 0xfc9d},
- {__uni_decomp_data_0xfc06, 0xfc06},
- {__uni_decomp_data_0xfdc2, 0xfdc2},
- {__uni_decomp_data_0xfc9e, 0xfc9e},
- {__uni_decomp_data_0xfc07, 0xfc07},
- {__uni_decomp_data_0xfd9e, 0xfd9e},
- {__uni_decomp_data_0xfc6a, 0xfc6a},
- {__uni_decomp_data_0xfc6b, 0xfc6b},
- {__uni_decomp_data_0xfce1, 0xfce1},
- {__uni_decomp_data_0xfc9f, 0xfc9f},
- {__uni_decomp_data_0xfc6c, 0xfc6c},
- {__uni_decomp_data_0xfc08, 0xfc08},
- {__uni_decomp_data_0xfc6d, 0xfc6d},
- {__uni_decomp_data_0xfca0, 0xfca0},
- {__uni_decomp_data_0xfce2, 0xfce2},
- {__uni_decomp_data_0xfc6e, 0xfc6e},
- {__uni_decomp_data_0xfc09, 0xfc09},
- {__uni_decomp_data_0xfc0a, 0xfc0a},
- {__uni_decomp_data_0xfc6f, 0xfc6f},
- {__uni_decomp_data_0xfc0b, 0xfc0b},
- {__uni_decomp_data_0xfca1, 0xfca1},
- {__uni_decomp_data_0xfd50, 0xfd50},
- {__uni_decomp_data_0xfda0, 0xfda0},
- {__uni_decomp_data_0xfd9f, 0xfd9f},
- {__uni_decomp_data_0xfc0c, 0xfc0c},
- {__uni_decomp_data_0xfca2, 0xfca2},
- {__uni_decomp_data_0xfd51, 0xfd51},
- {__uni_decomp_data_0xfd52, 0xfd52},
- {__uni_decomp_data_0xfd53, 0xfd53},
- {__uni_decomp_data_0xfca3, 0xfca3},
- {__uni_decomp_data_0xfc0d, 0xfc0d},
- {__uni_decomp_data_0xfd54, 0xfd54},
- {__uni_decomp_data_0xfda2, 0xfda2},
- {__uni_decomp_data_0xfda1, 0xfda1},
- {__uni_decomp_data_0xfc70, 0xfc70},
- {__uni_decomp_data_0xfc71, 0xfc71},
- {__uni_decomp_data_0xfc72, 0xfc72},
- {__uni_decomp_data_0xfc0e, 0xfc0e},
- {__uni_decomp_data_0xfca4, 0xfca4},
- {__uni_decomp_data_0xfce3, 0xfce3},
- {__uni_decomp_data_0xfd55, 0xfd55},
- {__uni_decomp_data_0xfd56, 0xfd56},
- {__uni_decomp_data_0xfd57, 0xfd57},
- {__uni_decomp_data_0xfda4, 0xfda4},
- {__uni_decomp_data_0xfda3, 0xfda3},
- {__uni_decomp_data_0xfc73, 0xfc73},
- {__uni_decomp_data_0xfca5, 0xfca5},
- {__uni_decomp_data_0xfce4, 0xfce4},
- {__uni_decomp_data_0xfc0f, 0xfc0f},
- {__uni_decomp_data_0xfc74, 0xfc74},
- {__uni_decomp_data_0xfc10, 0xfc10},
- {__uni_decomp_data_0xfc75, 0xfc75},
- {__uni_decomp_data_0xfc11, 0xfc11},
- {__uni_decomp_data_0xfc76, 0xfc76},
- {__uni_decomp_data_0xfc77, 0xfc77},
- {__uni_decomp_data_0xfc12, 0xfc12},
- {__uni_decomp_data_0xfc78, 0xfc78},
- {__uni_decomp_data_0xfca6, 0xfca6},
- {__uni_decomp_data_0xfce5, 0xfce5},
- {__uni_decomp_data_0xfc79, 0xfc79},
- {__uni_decomp_data_0xfce6, 0xfce6},
- {__uni_decomp_data_0xfc13, 0xfc13},
- {__uni_decomp_data_0xfc7a, 0xfc7a},
- {__uni_decomp_data_0xfc7b, 0xfc7b},
- {__uni_decomp_data_0xfc14, 0xfc14},
- {__uni_decomp_data_0xfca7, 0xfca7},
- {__uni_decomp_data_0xfc15, 0xfc15},
- {__uni_decomp_data_0xfda6, 0xfda6},
- {__uni_decomp_data_0xfdbe, 0xfdbe},
- {__uni_decomp_data_0xfdfb, 0xfdfb},
- {__uni_decomp_data_0xfca8, 0xfca8},
- {__uni_decomp_data_0xfc16, 0xfc16},
- {__uni_decomp_data_0xfd58, 0xfd58},
- {__uni_decomp_data_0xfd59, 0xfd59},
- {__uni_decomp_data_0xfda7, 0xfda7},
- {__uni_decomp_data_0xfda5, 0xfda5},
- {__uni_decomp_data_0xfd1d, 0xfd1d},
- {__uni_decomp_data_0xfd01, 0xfd01},
- {__uni_decomp_data_0xfd1e, 0xfd1e},
- {__uni_decomp_data_0xfd02, 0xfd02},
- {__uni_decomp_data_0xfc17, 0xfc17},
- {__uni_decomp_data_0xfca9, 0xfca9},
- {__uni_decomp_data_0xfdbf, 0xfdbf},
- {__uni_decomp_data_0xfcaa, 0xfcaa},
- {__uni_decomp_data_0xfc18, 0xfc18},
- {__uni_decomp_data_0xfd5b, 0xfd5b},
- {__uni_decomp_data_0xfd5a, 0xfd5a},
- {__uni_decomp_data_0xfd1b, 0xfd1b},
- {__uni_decomp_data_0xfcff, 0xfcff},
- {__uni_decomp_data_0xfd1c, 0xfd1c},
- {__uni_decomp_data_0xfd00, 0xfd00},
- {__uni_decomp_data_0xfcab, 0xfcab},
- {__uni_decomp_data_0xfc19, 0xfc19},
- {__uni_decomp_data_0xfc1a, 0xfc1a},
- {__uni_decomp_data_0xfc1b, 0xfc1b},
- {__uni_decomp_data_0xfcac, 0xfcac},
- {__uni_decomp_data_0xfd1f, 0xfd1f},
- {__uni_decomp_data_0xfd03, 0xfd03},
- {__uni_decomp_data_0xfd20, 0xfd20},
- {__uni_decomp_data_0xfd04, 0xfd04},
- {__uni_decomp_data_0xfc5b, 0xfc5b},
- {__uni_decomp_data_0xfdf6, 0xfdf6},
- {__uni_decomp_data_0xfc5c, 0xfc5c},
- {__uni_decomp_data_0xfdfc, 0xfdfc},
- {__uni_decomp_data_0xfcad, 0xfcad},
- {__uni_decomp_data_0xfc1c, 0xfc1c},
- {__uni_decomp_data_0xfd34, 0xfd34},
- {__uni_decomp_data_0xfd5d, 0xfd5d},
- {__uni_decomp_data_0xfd5e, 0xfd5e},
- {__uni_decomp_data_0xfc1d, 0xfc1d},
- {__uni_decomp_data_0xfcae, 0xfcae},
- {__uni_decomp_data_0xfd35, 0xfd35},
- {__uni_decomp_data_0xfd5c, 0xfd5c},
- {__uni_decomp_data_0xfc1e, 0xfc1e},
- {__uni_decomp_data_0xfcaf, 0xfcaf},
- {__uni_decomp_data_0xfd36, 0xfd36},
- {__uni_decomp_data_0xfda8, 0xfda8},
- {__uni_decomp_data_0xfdc6, 0xfdc6},
- {__uni_decomp_data_0xfd0e, 0xfd0e},
- {__uni_decomp_data_0xfd2a, 0xfd2a},
- {__uni_decomp_data_0xfcb0, 0xfcb0},
- {__uni_decomp_data_0xfce7, 0xfce7},
- {__uni_decomp_data_0xfc1f, 0xfc1f},
- {__uni_decomp_data_0xfd61, 0xfd61},
- {__uni_decomp_data_0xfd60, 0xfd60},
- {__uni_decomp_data_0xfd5f, 0xfd5f},
- {__uni_decomp_data_0xfd62, 0xfd62},
- {__uni_decomp_data_0xfd63, 0xfd63},
- {__uni_decomp_data_0xfd31, 0xfd31},
- {__uni_decomp_data_0xfce8, 0xfce8},
- {__uni_decomp_data_0xfd17, 0xfd17},
- {__uni_decomp_data_0xfcfb, 0xfcfb},
- {__uni_decomp_data_0xfd18, 0xfd18},
- {__uni_decomp_data_0xfcfc, 0xfcfc},
- {__uni_decomp_data_0xfd25, 0xfd25},
- {__uni_decomp_data_0xfd2d, 0xfd2d},
- {__uni_decomp_data_0xfd09, 0xfd09},
- {__uni_decomp_data_0xfd37, 0xfd37},
- {__uni_decomp_data_0xfd69, 0xfd69},
- {__uni_decomp_data_0xfd38, 0xfd38},
- {__uni_decomp_data_0xfd0a, 0xfd0a},
- {__uni_decomp_data_0xfd26, 0xfd26},
- {__uni_decomp_data_0xfd2e, 0xfd2e},
- {__uni_decomp_data_0xfd68, 0xfd68},
- {__uni_decomp_data_0xfd67, 0xfd67},
- {__uni_decomp_data_0xfdaa, 0xfdaa},
- {__uni_decomp_data_0xfd0b, 0xfd0b},
- {__uni_decomp_data_0xfd39, 0xfd39},
- {__uni_decomp_data_0xfd27, 0xfd27},
- {__uni_decomp_data_0xfd2f, 0xfd2f},
- {__uni_decomp_data_0xfd29, 0xfd29},
- {__uni_decomp_data_0xfd0d, 0xfd0d},
- {__uni_decomp_data_0xfd28, 0xfd28},
- {__uni_decomp_data_0xfce9, 0xfce9},
- {__uni_decomp_data_0xfd30, 0xfd30},
- {__uni_decomp_data_0xfd0c, 0xfd0c},
- {__uni_decomp_data_0xfd6b, 0xfd6b},
- {__uni_decomp_data_0xfd6a, 0xfd6a},
- {__uni_decomp_data_0xfd6d, 0xfd6d},
- {__uni_decomp_data_0xfd6c, 0xfd6c},
- {__uni_decomp_data_0xfd32, 0xfd32},
- {__uni_decomp_data_0xfcea, 0xfcea},
- {__uni_decomp_data_0xfcfd, 0xfcfd},
- {__uni_decomp_data_0xfd19, 0xfd19},
- {__uni_decomp_data_0xfd1a, 0xfd1a},
- {__uni_decomp_data_0xfcfe, 0xfcfe},
- {__uni_decomp_data_0xfcb1, 0xfcb1},
- {__uni_decomp_data_0xfc20, 0xfc20},
- {__uni_decomp_data_0xfd65, 0xfd65},
- {__uni_decomp_data_0xfd64, 0xfd64},
- {__uni_decomp_data_0xfda9, 0xfda9},
- {__uni_decomp_data_0xfcb2, 0xfcb2},
- {__uni_decomp_data_0xfd0f, 0xfd0f},
- {__uni_decomp_data_0xfd2b, 0xfd2b},
- {__uni_decomp_data_0xfdf5, 0xfdf5},
- {__uni_decomp_data_0xfdf9, 0xfdf9},
- {__uni_decomp_data_0xfdfa, 0xfdfa},
- {__uni_decomp_data_0xfdf0, 0xfdf0},
- {__uni_decomp_data_0xfc21, 0xfc21},
- {__uni_decomp_data_0xfcb3, 0xfcb3},
- {__uni_decomp_data_0xfdc5, 0xfdc5},
- {__uni_decomp_data_0xfd66, 0xfd66},
- {__uni_decomp_data_0xfd05, 0xfd05},
- {__uni_decomp_data_0xfd21, 0xfd21},
- {__uni_decomp_data_0xfd06, 0xfd06},
- {__uni_decomp_data_0xfd22, 0xfd22},
- {__uni_decomp_data_0xfcb4, 0xfcb4},
- {__uni_decomp_data_0xfc22, 0xfc22},
- {__uni_decomp_data_0xfc23, 0xfc23},
- {__uni_decomp_data_0xfcb5, 0xfcb5},
- {__uni_decomp_data_0xfd6e, 0xfd6e},
- {__uni_decomp_data_0xfdab, 0xfdab},
- {__uni_decomp_data_0xfc24, 0xfc24},
- {__uni_decomp_data_0xfcb6, 0xfcb6},
- {__uni_decomp_data_0xfd6f, 0xfd6f},
- {__uni_decomp_data_0xfd70, 0xfd70},
- {__uni_decomp_data_0xfd2c, 0xfd2c},
- {__uni_decomp_data_0xfd10, 0xfd10},
- {__uni_decomp_data_0xfcb7, 0xfcb7},
- {__uni_decomp_data_0xfc25, 0xfc25},
- {__uni_decomp_data_0xfd23, 0xfd23},
- {__uni_decomp_data_0xfd07, 0xfd07},
- {__uni_decomp_data_0xfd24, 0xfd24},
- {__uni_decomp_data_0xfd08, 0xfd08},
- {__uni_decomp_data_0xfcb8, 0xfcb8},
- {__uni_decomp_data_0xfc26, 0xfc26},
- {__uni_decomp_data_0xfd3a, 0xfd3a},
- {__uni_decomp_data_0xfc27, 0xfc27},
- {__uni_decomp_data_0xfd33, 0xfd33},
- {__uni_decomp_data_0xfd72, 0xfd72},
- {__uni_decomp_data_0xfd71, 0xfd71},
- {__uni_decomp_data_0xfd73, 0xfd73},
- {__uni_decomp_data_0xfd74, 0xfd74},
- {__uni_decomp_data_0xfd11, 0xfd11},
- {__uni_decomp_data_0xfcf5, 0xfcf5},
- {__uni_decomp_data_0xfd12, 0xfd12},
- {__uni_decomp_data_0xfcf6, 0xfcf6},
- {__uni_decomp_data_0xfcb9, 0xfcb9},
- {__uni_decomp_data_0xfd3b, 0xfd3b},
- {__uni_decomp_data_0xfc28, 0xfc28},
- {__uni_decomp_data_0xfcba, 0xfcba},
- {__uni_decomp_data_0xfc29, 0xfc29},
- {__uni_decomp_data_0xfdc4, 0xfdc4},
- {__uni_decomp_data_0xfd75, 0xfd75},
- {__uni_decomp_data_0xfdf7, 0xfdf7},
- {__uni_decomp_data_0xfcbb, 0xfcbb},
- {__uni_decomp_data_0xfc2a, 0xfc2a},
- {__uni_decomp_data_0xfd77, 0xfd77},
- {__uni_decomp_data_0xfd76, 0xfd76},
- {__uni_decomp_data_0xfd78, 0xfd78},
- {__uni_decomp_data_0xfdb6, 0xfdb6},
- {__uni_decomp_data_0xfd13, 0xfd13},
- {__uni_decomp_data_0xfcf7, 0xfcf7},
- {__uni_decomp_data_0xfd14, 0xfd14},
- {__uni_decomp_data_0xfcf8, 0xfcf8},
- {__uni_decomp_data_0xfc2b, 0xfc2b},
- {__uni_decomp_data_0xfcbc, 0xfcbc},
- {__uni_decomp_data_0xfc2c, 0xfc2c},
- {__uni_decomp_data_0xfcbd, 0xfcbd},
- {__uni_decomp_data_0xfd79, 0xfd79},
- {__uni_decomp_data_0xfd7b, 0xfd7b},
- {__uni_decomp_data_0xfd7a, 0xfd7a},
- {__uni_decomp_data_0xfcf9, 0xfcf9},
- {__uni_decomp_data_0xfd15, 0xfd15},
- {__uni_decomp_data_0xfcfa, 0xfcfa},
- {__uni_decomp_data_0xfd16, 0xfd16},
- {__uni_decomp_data_0xfe71, 0xfe71},
- {__uni_decomp_data_0xfe77, 0xfe77},
- {__uni_decomp_data_0xfcf2, 0xfcf2},
- {__uni_decomp_data_0xfe79, 0xfe79},
- {__uni_decomp_data_0xfcf3, 0xfcf3},
- {__uni_decomp_data_0xfe7b, 0xfe7b},
- {__uni_decomp_data_0xfcf4, 0xfcf4},
- {__uni_decomp_data_0xfe7d, 0xfe7d},
- {__uni_decomp_data_0xfe7f, 0xfe7f},
- {__uni_decomp_data_0xfc2d, 0xfc2d},
- {__uni_decomp_data_0xfcbe, 0xfcbe},
- {__uni_decomp_data_0xfc2e, 0xfc2e},
- {__uni_decomp_data_0xfcbf, 0xfcbf},
- {__uni_decomp_data_0xfc2f, 0xfc2f},
- {__uni_decomp_data_0xfcc0, 0xfcc0},
- {__uni_decomp_data_0xfd7d, 0xfd7d},
- {__uni_decomp_data_0xfd7c, 0xfd7c},
- {__uni_decomp_data_0xfc30, 0xfc30},
- {__uni_decomp_data_0xfcc1, 0xfcc1},
- {__uni_decomp_data_0xfdc1, 0xfdc1},
- {__uni_decomp_data_0xfc31, 0xfc31},
- {__uni_decomp_data_0xfc7c, 0xfc7c},
- {__uni_decomp_data_0xfc7d, 0xfc7d},
- {__uni_decomp_data_0xfc32, 0xfc32},
- {__uni_decomp_data_0xfcc2, 0xfcc2},
- {__uni_decomp_data_0xfc33, 0xfc33},
- {__uni_decomp_data_0xfdf1, 0xfdf1},
- {__uni_decomp_data_0xfc34, 0xfc34},
- {__uni_decomp_data_0xfcc3, 0xfcc3},
- {__uni_decomp_data_0xfdb4, 0xfdb4},
- {__uni_decomp_data_0xfd7e, 0xfd7e},
- {__uni_decomp_data_0xfd7f, 0xfd7f},
- {__uni_decomp_data_0xfdb2, 0xfdb2},
- {__uni_decomp_data_0xfc35, 0xfc35},
- {__uni_decomp_data_0xfc7e, 0xfc7e},
- {__uni_decomp_data_0xfc36, 0xfc36},
- {__uni_decomp_data_0xfc7f, 0xfc7f},
- {__uni_decomp_data_0xfc80, 0xfc80},
- {__uni_decomp_data_0xfc37, 0xfc37},
- {__uni_decomp_data_0xfcc4, 0xfcc4},
- {__uni_decomp_data_0xfc38, 0xfc38},
- {__uni_decomp_data_0xfc39, 0xfc39},
- {__uni_decomp_data_0xfcc5, 0xfcc5},
- {__uni_decomp_data_0xfcc6, 0xfcc6},
- {__uni_decomp_data_0xfc3a, 0xfc3a},
- {__uni_decomp_data_0xfcc7, 0xfcc7},
- {__uni_decomp_data_0xfceb, 0xfceb},
- {__uni_decomp_data_0xfc81, 0xfc81},
- {__uni_decomp_data_0xfc3b, 0xfc3b},
- {__uni_decomp_data_0xfcc8, 0xfcc8},
- {__uni_decomp_data_0xfc82, 0xfc82},
- {__uni_decomp_data_0xfc3c, 0xfc3c},
- {__uni_decomp_data_0xfcec, 0xfcec},
- {__uni_decomp_data_0xfdc3, 0xfdc3},
- {__uni_decomp_data_0xfdbb, 0xfdbb},
- {__uni_decomp_data_0xfdb7, 0xfdb7},
- {__uni_decomp_data_0xfc83, 0xfc83},
- {__uni_decomp_data_0xfc3d, 0xfc3d},
- {__uni_decomp_data_0xfc3e, 0xfc3e},
- {__uni_decomp_data_0xfc84, 0xfc84},
- {__uni_decomp_data_0xfef6, 0xfef6},
- {__uni_decomp_data_0xfef5, 0xfef5},
- {__uni_decomp_data_0xfef7, 0xfef7},
- {__uni_decomp_data_0xfef8, 0xfef8},
- {__uni_decomp_data_0xfef9, 0xfef9},
- {__uni_decomp_data_0xfefa, 0xfefa},
- {__uni_decomp_data_0xfefb, 0xfefb},
- {__uni_decomp_data_0xfefc, 0xfefc},
- {__uni_decomp_data_0xfc3f, 0xfc3f},
- {__uni_decomp_data_0xfcc9, 0xfcc9},
- {__uni_decomp_data_0xfd84, 0xfd84},
- {__uni_decomp_data_0xfd83, 0xfd83},
- {__uni_decomp_data_0xfdbc, 0xfdbc},
- {__uni_decomp_data_0xfdba, 0xfdba},
- {__uni_decomp_data_0xfdac, 0xfdac},
- {__uni_decomp_data_0xfcca, 0xfcca},
- {__uni_decomp_data_0xfc40, 0xfc40},
- {__uni_decomp_data_0xfd80, 0xfd80},
- {__uni_decomp_data_0xfdb5, 0xfdb5},
- {__uni_decomp_data_0xfd82, 0xfd82},
- {__uni_decomp_data_0xfd81, 0xfd81},
- {__uni_decomp_data_0xfccb, 0xfccb},
- {__uni_decomp_data_0xfc41, 0xfc41},
- {__uni_decomp_data_0xfd85, 0xfd85},
- {__uni_decomp_data_0xfd86, 0xfd86},
- {__uni_decomp_data_0xfccc, 0xfccc},
- {__uni_decomp_data_0xfced, 0xfced},
- {__uni_decomp_data_0xfc42, 0xfc42},
- {__uni_decomp_data_0xfc85, 0xfc85},
- {__uni_decomp_data_0xfd87, 0xfd87},
- {__uni_decomp_data_0xfd88, 0xfd88},
- {__uni_decomp_data_0xfdad, 0xfdad},
- {__uni_decomp_data_0xfccd, 0xfccd},
- {__uni_decomp_data_0xfc86, 0xfc86},
- {__uni_decomp_data_0xfc43, 0xfc43},
- {__uni_decomp_data_0xfc87, 0xfc87},
- {__uni_decomp_data_0xfc44, 0xfc44},
- {__uni_decomp_data_0xfc88, 0xfc88},
- {__uni_decomp_data_0xfcce, 0xfcce},
- {__uni_decomp_data_0xfc45, 0xfc45},
- {__uni_decomp_data_0xfd8c, 0xfd8c},
- {__uni_decomp_data_0xfd92, 0xfd92},
- {__uni_decomp_data_0xfd8d, 0xfd8d},
- {__uni_decomp_data_0xfdc0, 0xfdc0},
- {__uni_decomp_data_0xfccf, 0xfccf},
- {__uni_decomp_data_0xfc46, 0xfc46},
- {__uni_decomp_data_0xfd89, 0xfd89},
- {__uni_decomp_data_0xfd8a, 0xfd8a},
- {__uni_decomp_data_0xfdf4, 0xfdf4},
- {__uni_decomp_data_0xfd8b, 0xfd8b},
- {__uni_decomp_data_0xfc47, 0xfc47},
- {__uni_decomp_data_0xfcd0, 0xfcd0},
- {__uni_decomp_data_0xfd8e, 0xfd8e},
- {__uni_decomp_data_0xfd8f, 0xfd8f},
- {__uni_decomp_data_0xfdb9, 0xfdb9},
- {__uni_decomp_data_0xfc48, 0xfc48},
- {__uni_decomp_data_0xfcd1, 0xfcd1},
- {__uni_decomp_data_0xfc89, 0xfc89},
- {__uni_decomp_data_0xfdb1, 0xfdb1},
- {__uni_decomp_data_0xfc49, 0xfc49},
- {__uni_decomp_data_0xfc4a, 0xfc4a},
- {__uni_decomp_data_0xfcd2, 0xfcd2},
- {__uni_decomp_data_0xfc4b, 0xfc4b},
- {__uni_decomp_data_0xfdbd, 0xfdbd},
- {__uni_decomp_data_0xfdb8, 0xfdb8},
- {__uni_decomp_data_0xfd98, 0xfd98},
- {__uni_decomp_data_0xfd97, 0xfd97},
- {__uni_decomp_data_0xfd99, 0xfd99},
- {__uni_decomp_data_0xfdc7, 0xfdc7},
- {__uni_decomp_data_0xfc4c, 0xfc4c},
- {__uni_decomp_data_0xfcd3, 0xfcd3},
- {__uni_decomp_data_0xfd95, 0xfd95},
- {__uni_decomp_data_0xfd96, 0xfd96},
- {__uni_decomp_data_0xfdb3, 0xfdb3},
- {__uni_decomp_data_0xfc4d, 0xfc4d},
- {__uni_decomp_data_0xfcd4, 0xfcd4},
- {__uni_decomp_data_0xfc8a, 0xfc8a},
- {__uni_decomp_data_0xfc8b, 0xfc8b},
- {__uni_decomp_data_0xfc4e, 0xfc4e},
- {__uni_decomp_data_0xfcd5, 0xfcd5},
- {__uni_decomp_data_0xfc8c, 0xfc8c},
- {__uni_decomp_data_0xfcee, 0xfcee},
- {__uni_decomp_data_0xfd9b, 0xfd9b},
- {__uni_decomp_data_0xfd9a, 0xfd9a},
- {__uni_decomp_data_0xfc8d, 0xfc8d},
- {__uni_decomp_data_0xfcd6, 0xfcd6},
- {__uni_decomp_data_0xfcef, 0xfcef},
- {__uni_decomp_data_0xfc8e, 0xfc8e},
- {__uni_decomp_data_0xfc4f, 0xfc4f},
- {__uni_decomp_data_0xfc8f, 0xfc8f},
- {__uni_decomp_data_0xfc50, 0xfc50},
- {__uni_decomp_data_0xfc51, 0xfc51},
- {__uni_decomp_data_0xfcd7, 0xfcd7},
- {__uni_decomp_data_0xfc52, 0xfc52},
- {__uni_decomp_data_0xfcd8, 0xfcd8},
- {__uni_decomp_data_0xfd93, 0xfd93},
- {__uni_decomp_data_0xfd94, 0xfd94},
- {__uni_decomp_data_0xfc53, 0xfc53},
- {__uni_decomp_data_0xfc54, 0xfc54},
- {__uni_decomp_data_0xfcd9, 0xfcd9},
- {__uni_decomp_data_0xfdf8, 0xfdf8},
         {__uni_decomp_data_0x624, 0x624},
- {__uni_decomp_data_0x676, 0x676},
- {__uni_decomp_data_0xfc90, 0xfc90},
- {__uni_decomp_data_0xfc5d, 0xfc5d},
- {__uni_decomp_data_0xfc55, 0xfc55},
- {__uni_decomp_data_0xfcda, 0xfcda},
- {__uni_decomp_data_0xfdaf, 0xfdaf},
- {__uni_decomp_data_0xfc56, 0xfc56},
- {__uni_decomp_data_0xfcdb, 0xfcdb},
- {__uni_decomp_data_0xfdae, 0xfdae},
- {__uni_decomp_data_0xfc57, 0xfc57},
- {__uni_decomp_data_0xfcdc, 0xfcdc},
- {__uni_decomp_data_0xfc91, 0xfc91},
- {__uni_decomp_data_0xfc92, 0xfc92},
- {__uni_decomp_data_0xfcf0, 0xfcf0},
- {__uni_decomp_data_0xfcdd, 0xfcdd},
- {__uni_decomp_data_0xfc58, 0xfc58},
- {__uni_decomp_data_0xfc93, 0xfc93},
- {__uni_decomp_data_0xfd9c, 0xfd9c},
- {__uni_decomp_data_0xfd9d, 0xfd9d},
- {__uni_decomp_data_0xfdb0, 0xfdb0},
- {__uni_decomp_data_0xfc94, 0xfc94},
- {__uni_decomp_data_0xfcf1, 0xfcf1},
- {__uni_decomp_data_0xfcde, 0xfcde},
- {__uni_decomp_data_0xfc59, 0xfc59},
- {__uni_decomp_data_0xfc95, 0xfc95},
- {__uni_decomp_data_0xfc5a, 0xfc5a},
- {__uni_decomp_data_0xfc96, 0xfc96},
         {__uni_decomp_data_0x626, 0x626},
- {__uni_decomp_data_0x678, 0x678},
         {__uni_decomp_data_0x6c2, 0x6c2},
- {__uni_decomp_data_0x677, 0x677},
         {__uni_decomp_data_0x6d3, 0x6d3},
         {__uni_decomp_data_0x6c0, 0x6c0},
         {__uni_decomp_data_0x929, 0x929},
@@ -1646,30 +692,7 @@
         {__uni_decomp_data_0xddc, 0xddc},
         {__uni_decomp_data_0xdde, 0xdde},
         {__uni_decomp_data_0xddd, 0xddd},
- {__uni_decomp_data_0xe33, 0xe33},
- {__uni_decomp_data_0xedc, 0xedc},
- {__uni_decomp_data_0xedd, 0xedd},
- {__uni_decomp_data_0xeb3, 0xeb3},
- {__uni_decomp_data_0xf77, 0xf77},
- {__uni_decomp_data_0xf79, 0xf79},
         {__uni_decomp_data_0x1026, 0x1026},
- {__uni_decomp_data_0x326e, 0x326e},
- {__uni_decomp_data_0x326f, 0x326f},
- {__uni_decomp_data_0x3270, 0x3270},
- {__uni_decomp_data_0x3271, 0x3271},
- {__uni_decomp_data_0x3272, 0x3272},
- {__uni_decomp_data_0x3273, 0x3273},
- {__uni_decomp_data_0x3274, 0x3274},
- {__uni_decomp_data_0x3275, 0x3275},
- {__uni_decomp_data_0x327e, 0x327e},
- {__uni_decomp_data_0x3276, 0x3276},
- {__uni_decomp_data_0x327d, 0x327d},
- {__uni_decomp_data_0x3277, 0x3277},
- {__uni_decomp_data_0x327c, 0x327c},
- {__uni_decomp_data_0x3278, 0x3278},
- {__uni_decomp_data_0x3279, 0x3279},
- {__uni_decomp_data_0x327a, 0x327a},
- {__uni_decomp_data_0x327b, 0x327b},
         {__uni_decomp_data_0x1b06, 0x1b06},
         {__uni_decomp_data_0x1b08, 0x1b08},
         {__uni_decomp_data_0x1b0a, 0x1b0a},
@@ -1828,11 +851,6 @@
         {__uni_decomp_data_0x1fdd, 0x1fdd},
         {__uni_decomp_data_0x1fde, 0x1fde},
         {__uni_decomp_data_0x1fdf, 0x1fdf},
- {__uni_decomp_data_0x2033, 0x2033},
- {__uni_decomp_data_0x2034, 0x2034},
- {__uni_decomp_data_0x2057, 0x2057},
- {__uni_decomp_data_0x2036, 0x2036},
- {__uni_decomp_data_0x2037, 0x2037},
         {__uni_decomp_data_0x219a, 0x219a},
         {__uni_decomp_data_0x219b, 0x219b},
         {__uni_decomp_data_0x21ae, 0x21ae},
@@ -1844,11 +862,6 @@
         {__uni_decomp_data_0x220c, 0x220c},
         {__uni_decomp_data_0x2224, 0x2224},
         {__uni_decomp_data_0x2226, 0x2226},
- {__uni_decomp_data_0x222c, 0x222c},
- {__uni_decomp_data_0x222d, 0x222d},
- {__uni_decomp_data_0x2a0c, 0x2a0c},
- {__uni_decomp_data_0x222f, 0x222f},
- {__uni_decomp_data_0x2230, 0x2230},
         {__uni_decomp_data_0x2241, 0x2241},
         {__uni_decomp_data_0x2244, 0x2244},
         {__uni_decomp_data_0x2247, 0x2247},
@@ -1905,133 +918,38 @@
         {__uni_decomp_data_0x307a, 0x307a},
         {__uni_decomp_data_0x307c, 0x307c},
         {__uni_decomp_data_0x307d, 0x307d},
- {__uni_decomp_data_0x309f, 0x309f},
         {__uni_decomp_data_0x309e, 0x309e},
- {__uni_decomp_data_0x3300, 0x3300},
- {__uni_decomp_data_0x3301, 0x3301},
- {__uni_decomp_data_0x3302, 0x3302},
- {__uni_decomp_data_0x3303, 0x3303},
- {__uni_decomp_data_0x3304, 0x3304},
- {__uni_decomp_data_0x3305, 0x3305},
         {__uni_decomp_data_0x30f4, 0x30f4},
- {__uni_decomp_data_0x3306, 0x3306},
- {__uni_decomp_data_0x3307, 0x3307},
- {__uni_decomp_data_0x3308, 0x3308},
- {__uni_decomp_data_0x3309, 0x3309},
- {__uni_decomp_data_0x330a, 0x330a},
         {__uni_decomp_data_0x30ac, 0x30ac},
- {__uni_decomp_data_0x330b, 0x330b},
- {__uni_decomp_data_0x330c, 0x330c},
- {__uni_decomp_data_0x330d, 0x330d},
- {__uni_decomp_data_0x330e, 0x330e},
- {__uni_decomp_data_0x330f, 0x330f},
         {__uni_decomp_data_0x30ae, 0x30ae},
- {__uni_decomp_data_0x3312, 0x3312},
- {__uni_decomp_data_0x3314, 0x3314},
- {__uni_decomp_data_0x3315, 0x3315},
- {__uni_decomp_data_0x3316, 0x3316},
- {__uni_decomp_data_0x3317, 0x3317},
- {__uni_decomp_data_0x3310, 0x3310},
- {__uni_decomp_data_0x3311, 0x3311},
- {__uni_decomp_data_0x3313, 0x3313},
         {__uni_decomp_data_0x30b0, 0x30b0},
- {__uni_decomp_data_0x331a, 0x331a},
- {__uni_decomp_data_0x331b, 0x331b},
- {__uni_decomp_data_0x3318, 0x3318},
- {__uni_decomp_data_0x3319, 0x3319},
         {__uni_decomp_data_0x30b2, 0x30b2},
- {__uni_decomp_data_0x331c, 0x331c},
         {__uni_decomp_data_0x30b4, 0x30b4},
- {__uni_decomp_data_0x30ff, 0x30ff},
- {__uni_decomp_data_0x331d, 0x331d},
- {__uni_decomp_data_0x331e, 0x331e},
         {__uni_decomp_data_0x30b6, 0x30b6},
- {__uni_decomp_data_0x331f, 0x331f},
- {__uni_decomp_data_0x3320, 0x3320},
         {__uni_decomp_data_0x30b8, 0x30b8},
- {__uni_decomp_data_0x3321, 0x3321},
         {__uni_decomp_data_0x30ba, 0x30ba},
         {__uni_decomp_data_0x30bc, 0x30bc},
- {__uni_decomp_data_0x3322, 0x3322},
- {__uni_decomp_data_0x3323, 0x3323},
         {__uni_decomp_data_0x30be, 0x30be},
         {__uni_decomp_data_0x30c0, 0x30c0},
- {__uni_decomp_data_0x3324, 0x3324},
         {__uni_decomp_data_0x30c2, 0x30c2},
         {__uni_decomp_data_0x30c5, 0x30c5},
         {__uni_decomp_data_0x30c7, 0x30c7},
- {__uni_decomp_data_0x3325, 0x3325},
         {__uni_decomp_data_0x30c9, 0x30c9},
- {__uni_decomp_data_0x3327, 0x3327},
- {__uni_decomp_data_0x3326, 0x3326},
- {__uni_decomp_data_0x3328, 0x3328},
- {__uni_decomp_data_0x3329, 0x3329},
         {__uni_decomp_data_0x30d0, 0x30d0},
         {__uni_decomp_data_0x30d1, 0x30d1},
- {__uni_decomp_data_0x332a, 0x332a},
- {__uni_decomp_data_0x332d, 0x332d},
- {__uni_decomp_data_0x332b, 0x332b},
- {__uni_decomp_data_0x332c, 0x332c},
         {__uni_decomp_data_0x30d3, 0x30d3},
         {__uni_decomp_data_0x30d4, 0x30d4},
- {__uni_decomp_data_0x3331, 0x3331},
- {__uni_decomp_data_0x332e, 0x332e},
- {__uni_decomp_data_0x332f, 0x332f},
- {__uni_decomp_data_0x3330, 0x3330},
         {__uni_decomp_data_0x30d6, 0x30d6},
         {__uni_decomp_data_0x30d7, 0x30d7},
- {__uni_decomp_data_0x3332, 0x3332},
- {__uni_decomp_data_0x3333, 0x3333},
- {__uni_decomp_data_0x3335, 0x3335},
- {__uni_decomp_data_0x3334, 0x3334},
         {__uni_decomp_data_0x30d9, 0x30d9},
         {__uni_decomp_data_0x30da, 0x30da},
- {__uni_decomp_data_0x3336, 0x3336},
- {__uni_decomp_data_0x3339, 0x3339},
- {__uni_decomp_data_0x333c, 0x333c},
- {__uni_decomp_data_0x3337, 0x3337},
- {__uni_decomp_data_0x3338, 0x3338},
- {__uni_decomp_data_0x333a, 0x333a},
- {__uni_decomp_data_0x333b, 0x333b},
         {__uni_decomp_data_0x30dc, 0x30dc},
         {__uni_decomp_data_0x30dd, 0x30dd},
- {__uni_decomp_data_0x333f, 0x333f},
- {__uni_decomp_data_0x3341, 0x3341},
- {__uni_decomp_data_0x3342, 0x3342},
- {__uni_decomp_data_0x333e, 0x333e},
- {__uni_decomp_data_0x333d, 0x333d},
- {__uni_decomp_data_0x3340, 0x3340},
- {__uni_decomp_data_0x3343, 0x3343},
- {__uni_decomp_data_0x3344, 0x3344},
- {__uni_decomp_data_0x3345, 0x3345},
- {__uni_decomp_data_0x3346, 0x3346},
- {__uni_decomp_data_0x3347, 0x3347},
- {__uni_decomp_data_0x3348, 0x3348},
- {__uni_decomp_data_0x3349, 0x3349},
- {__uni_decomp_data_0x334a, 0x334a},
- {__uni_decomp_data_0x334b, 0x334b},
- {__uni_decomp_data_0x334c, 0x334c},
- {__uni_decomp_data_0x334d, 0x334d},
- {__uni_decomp_data_0x334e, 0x334e},
- {__uni_decomp_data_0x334f, 0x334f},
- {__uni_decomp_data_0x3350, 0x3350},
- {__uni_decomp_data_0x3351, 0x3351},
- {__uni_decomp_data_0x3352, 0x3352},
- {__uni_decomp_data_0x3353, 0x3353},
- {__uni_decomp_data_0x3354, 0x3354},
- {__uni_decomp_data_0x3355, 0x3355},
- {__uni_decomp_data_0x3356, 0x3356},
         {__uni_decomp_data_0x30f7, 0x30f7},
- {__uni_decomp_data_0x3357, 0x3357},
         {__uni_decomp_data_0x30f8, 0x30f8},
         {__uni_decomp_data_0x30f9, 0x30f9},
         {__uni_decomp_data_0x30fa, 0x30fa},
         {__uni_decomp_data_0x30fe, 0x30fe},
- {__uni_decomp_data_0x337d, 0x337d},
- {__uni_decomp_data_0x337b, 0x337b},
- {__uni_decomp_data_0x337e, 0x337e},
- {__uni_decomp_data_0x337c, 0x337c},
- {__uni_decomp_data_0x337f, 0x337f},
 };
 
 BOOST_UNICODE_DECL extern const size_t __uni_compose_entry_size = sizeof __uni_compose_entry / sizeof __uni_compose_entry[0];

Modified: sandbox/SOC/2009/unicode/libs/unicode/src/ucd/uni_ucd_interface_impl_data_7.ipp
==============================================================================
--- sandbox/SOC/2009/unicode/libs/unicode/src/ucd/uni_ucd_interface_impl_data_7.ipp (original)
+++ sandbox/SOC/2009/unicode/libs/unicode/src/ucd/uni_ucd_interface_impl_data_7.ipp 2009-08-07 23:06:01 EDT (Fri, 07 Aug 2009)
@@ -6493,7 +6493,7 @@
                         category::punctuation_other,
                         word_break::midnum,
                         bidi_class::weak_common_number_separator,
- decomposition_type::small,
+ decomposition_type::small_,
                         line_break::closing_punctuation,
                         0,
                         sentence_break::scontinue,
@@ -6506,7 +6506,7 @@
                         category::punctuation_other,
                         word_break::any,
                         bidi_class::neutral_other,
- decomposition_type::small,
+ decomposition_type::small_,
                         line_break::ideograph,
                         0,
                         sentence_break::scontinue,
@@ -6519,7 +6519,7 @@
                         category::punctuation_other,
                         word_break::midnumlet,
                         bidi_class::weak_common_number_separator,
- decomposition_type::small,
+ decomposition_type::small_,
                         line_break::closing_punctuation,
                         0,
                         sentence_break::aterm,
@@ -6545,7 +6545,7 @@
                         category::punctuation_other,
                         word_break::midnum,
                         bidi_class::neutral_other,
- decomposition_type::small,
+ decomposition_type::small_,
                         line_break::non_starter,
                         0,
                         sentence_break::any,
@@ -6558,7 +6558,7 @@
                         category::punctuation_other,
                         word_break::midletter,
                         bidi_class::weak_common_number_separator,
- decomposition_type::small,
+ decomposition_type::small_,
                         line_break::non_starter,
                         0,
                         sentence_break::scontinue,
@@ -6571,7 +6571,7 @@
                         category::punctuation_other,
                         word_break::any,
                         bidi_class::neutral_other,
- decomposition_type::small,
+ decomposition_type::small_,
                         line_break::exclamation_interrogation,
                         0,
                         sentence_break::sterm,
@@ -6584,7 +6584,7 @@
                         category::punctuation_other,
                         word_break::any,
                         bidi_class::neutral_other,
- decomposition_type::small,
+ decomposition_type::small_,
                         line_break::exclamation_interrogation,
                         0,
                         sentence_break::sterm,
@@ -6597,7 +6597,7 @@
                         category::punctuation_dash,
                         word_break::any,
                         bidi_class::neutral_other,
- decomposition_type::small,
+ decomposition_type::small_,
                         line_break::ideograph,
                         0,
                         sentence_break::scontinue,
@@ -6610,7 +6610,7 @@
                         category::punctuation_open,
                         word_break::any,
                         bidi_class::neutral_other,
- decomposition_type::small,
+ decomposition_type::small_,
                         line_break::opening_punctuation,
                         0,
                         sentence_break::close,
@@ -6623,7 +6623,7 @@
                         category::punctuation_close,
                         word_break::any,
                         bidi_class::neutral_other,
- decomposition_type::small,
+ decomposition_type::small_,
                         line_break::closing_punctuation,
                         0,
                         sentence_break::close,
@@ -6636,7 +6636,7 @@
                         category::punctuation_open,
                         word_break::any,
                         bidi_class::neutral_other,
- decomposition_type::small,
+ decomposition_type::small_,
                         line_break::opening_punctuation,
                         0,
                         sentence_break::close,
@@ -6649,7 +6649,7 @@
                         category::punctuation_close,
                         word_break::any,
                         bidi_class::neutral_other,
- decomposition_type::small,
+ decomposition_type::small_,
                         line_break::closing_punctuation,
                         0,
                         sentence_break::close,
@@ -6662,7 +6662,7 @@
                         category::punctuation_open,
                         word_break::any,
                         bidi_class::neutral_other,
- decomposition_type::small,
+ decomposition_type::small_,
                         line_break::opening_punctuation,
                         0,
                         sentence_break::close,
@@ -6675,7 +6675,7 @@
                         category::punctuation_close,
                         word_break::any,
                         bidi_class::neutral_other,
- decomposition_type::small,
+ decomposition_type::small_,
                         line_break::closing_punctuation,
                         0,
                         sentence_break::close,
@@ -6688,7 +6688,7 @@
                         category::punctuation_other,
                         word_break::any,
                         bidi_class::weak_european_number_terminator,
- decomposition_type::small,
+ decomposition_type::small_,
                         line_break::ideograph,
                         0,
                         sentence_break::any,
@@ -6701,7 +6701,7 @@
                         category::punctuation_other,
                         word_break::any,
                         bidi_class::neutral_other,
- decomposition_type::small,
+ decomposition_type::small_,
                         line_break::ideograph,
                         0,
                         sentence_break::any,
@@ -6714,7 +6714,7 @@
                         category::punctuation_other,
                         word_break::any,
                         bidi_class::neutral_other,
- decomposition_type::small,
+ decomposition_type::small_,
                         line_break::ideograph,
                         0,
                         sentence_break::any,
@@ -6727,7 +6727,7 @@
                         category::symbol_math,
                         word_break::any,
                         bidi_class::weak_european_number_separator,
- decomposition_type::small,
+ decomposition_type::small_,
                         line_break::ideograph,
                         0,
                         sentence_break::any,
@@ -6740,7 +6740,7 @@
                         category::punctuation_dash,
                         word_break::any,
                         bidi_class::weak_european_number_separator,
- decomposition_type::small,
+ decomposition_type::small_,
                         line_break::ideograph,
                         0,
                         sentence_break::scontinue,
@@ -6753,7 +6753,7 @@
                         category::symbol_math,
                         word_break::any,
                         bidi_class::neutral_other,
- decomposition_type::small,
+ decomposition_type::small_,
                         line_break::ideograph,
                         0,
                         sentence_break::any,
@@ -6766,7 +6766,7 @@
                         category::symbol_math,
                         word_break::any,
                         bidi_class::neutral_other,
- decomposition_type::small,
+ decomposition_type::small_,
                         line_break::ideograph,
                         0,
                         sentence_break::any,
@@ -6779,7 +6779,7 @@
                         category::symbol_math,
                         word_break::any,
                         bidi_class::neutral_other,
- decomposition_type::small,
+ decomposition_type::small_,
                         line_break::ideograph,
                         0,
                         sentence_break::any,
@@ -6805,7 +6805,7 @@
                         category::punctuation_other,
                         word_break::any,
                         bidi_class::neutral_other,
- decomposition_type::small,
+ decomposition_type::small_,
                         line_break::ideograph,
                         0,
                         sentence_break::any,
@@ -6818,7 +6818,7 @@
                         category::symbol_currency,
                         word_break::any,
                         bidi_class::weak_european_number_terminator,
- decomposition_type::small,
+ decomposition_type::small_,
                         line_break::prefix_numeric,
                         0,
                         sentence_break::any,
@@ -6831,7 +6831,7 @@
                         category::punctuation_other,
                         word_break::any,
                         bidi_class::weak_european_number_terminator,
- decomposition_type::small,
+ decomposition_type::small_,
                         line_break::postfix_numeric,
                         0,
                         sentence_break::any,
@@ -6844,7 +6844,7 @@
                         category::punctuation_other,
                         word_break::any,
                         bidi_class::neutral_other,
- decomposition_type::small,
+ decomposition_type::small_,
                         line_break::ideograph,
                         0,
                         sentence_break::any,

Modified: sandbox/SOC/2009/unicode/libs/unicode/src/unicode_properties.cpp
==============================================================================
--- sandbox/SOC/2009/unicode/libs/unicode/src/unicode_properties.cpp (original)
+++ sandbox/SOC/2009/unicode/libs/unicode/src/unicode_properties.cpp 2009-08-07 23:06:01 EDT (Fri, 07 Aug 2009)
@@ -202,7 +202,7 @@
         "vertical",
         "wide",
         "narrow",
- "small",
+ "small_",
         "square",
         "fraction",
         "compat",


Boost-Commit list run by bdawes at acm.org, david.abrahams at rcn.com, gregod at cs.rpi.edu, cpdaniel at pacbell.net, john at johnmaddock.co.uk
--- sandbox/SOC/2009/unicode/libs/unicode/data_parser/write_character_properties.cpp (original)
+++ sandbox/SOC/2009/unicode/libs/unicode/data_parser/write_character_properties.cpp 2009-08-07 23:06:01 EDT (Fri, 07 Aug 2009)
@@ -86,7 +86,9 @@
 {
         // it would be very nice to checksum the whole of the entry in one
         // go but alignment might mean that there is random data interspersed
+#ifdef BOOST_UNICODE_UCD_BIG
         crc.process_bytes(name.c_str(), name.size() );
+#endif
         crc.process_bytes(&general_category, sizeof(general_category) );
         crc.process_bytes(&combining, sizeof(combining) );
         crc.process_bytes(&bidi, sizeof(bidi) );
@@ -96,6 +98,7 @@
         crc.process_bytes(&word_break_kind, sizeof(word_break_kind) );
         crc.process_bytes(&sentence_break_kind, sizeof(sentence_break_kind) );
         crc.process_bytes(&unknown_char, sizeof(unknown_char) );
+#ifdef BOOST_UNICODE_UCD_BIG
         crc.process_bytes(&sort_variable, sizeof(sort_variable) );
         crc.process_bytes(&sort_type, sizeof(sort_type) );
         crc.process_bytes(&sort_index_or_data1, sizeof(sort_index_or_data1) );
@@ -104,8 +107,11 @@
         crc.process_bytes(&lowercase, sizeof(lowercase) );
         crc.process_bytes(&titlecase, sizeof(titlecase) );
         crc.process_bytes(&has_complex_case, sizeof(has_complex_case) );
+#endif
         crc.process_bytes(&line_break, sizeof(line_break) );
+#ifdef BOOST_UNICODE_UCD_BIG
         crc.process_bytes(&joining, sizeof(joining) );
+#endif
 }
 
 bool write_entry::has_same_properties(const write_entry& other) const
@@ -1301,15 +1307,24 @@
 
 struct lexico_sort
 {
- bool operator()(const decomp_entry& lft, const decomp_entry& rgt) const
+ bool operator()(const decomp_entry* lft, const decomp_entry* rgt) const
     {
         return std::lexicographical_compare(
- lft.decomposition.begin(), lft.decomposition.end(),
- rgt.decomposition.begin(), rgt.decomposition.end()
+ lft->decomposition.begin(), lft->decomposition.end(),
+ rgt->decomposition.begin(), rgt->decomposition.end()
         );
     }
 };
 
+struct lexico_comp
+{
+ bool operator()(const decomp_entry* lft, const decomp_entry* rgt) const
+ {
+ return lft->decomposition.size() == rgt->decomposition.size()
+ && std::equal(lft->decomposition.begin(), lft->decomposition.end(), rgt->decomposition.begin());
+ }
+};
+
 const character_properties& get_properties(const std::map<char32, character_properties>& props, char32 ch)
 {
     std::map<char32, character_properties>::const_iterator it = props.find(ch);
@@ -1344,21 +1359,36 @@
 
         // ---- compose data table ------------------------------------------------------
     
- std::vector<decomp_entry> tmp = data.tbl_decomp;
- std::sort(tmp.begin(), tmp.end(), lexico_sort());
-
- file << "\nBOOST_UNICODE_DECL extern const unichar_compose_data_entry __uni_compose_entry[] = {\n";
+ std::vector<const decomp_entry*> compose;
+ compose.reserve(data.tbl_decomp.size());
     
- for(std::vector<decomp_entry>::const_iterator it = tmp.begin(); it != tmp.end(); ++it)
+ for(std::vector<decomp_entry>::const_iterator it = data.tbl_decomp.begin(); it != data.tbl_decomp.end(); ++it)
     {
/* We exclude singletons, decompositions that start with non-starters, and code points from the exclusion table */
         if(
- it->decomposition.size() > 1
- && get_properties(*data.props, it->decomposition[0]).combining == 0
- && !get_properties(*data.props, it->chr).comp_ex
+ get_properties(*data.props, it->chr).decomposition_kind == ucd::decomposition_type::canonical &&
+ it->decomposition.size() > 1 &&
+ get_properties(*data.props, it->decomposition[0]).combining == 0 &&
+ !get_properties(*data.props, it->chr).comp_ex
         )
- file << "\t{__uni_decomp_data_0x" << std::hex << it->chr << ", 0x" << it->chr << "},\n";
+ compose.push_back(&*it);
+ }
+
+ std::sort(compose.begin(), compose.end(), lexico_sort());
+ std::vector<const decomp_entry*>::iterator end = std::unique(compose.begin(), compose.end(), lexico_comp());
+ if(end != compose.end())
+ {
+ std::stringstream ss;
+ ss << "Duplicates found for canonical composition";
+ throw std::runtime_error (ss.str());
     }
+
+ file << "\nBOOST_UNICODE_DECL extern const unichar_compose_data_entry __uni_compose_entry[] = {\n";
+
+ for(std::vector<const decomp_entry*>::const_iterator it = compose.begin(); it != compose.end(); ++it)
+ file << "\t{__uni_decomp_data_0x" << std::hex << (*it)->chr << ", 0x" << (*it)->chr << "},\n";
     
     file << "};\n\n";
     file << "BOOST_UNICODE_DECL extern const size_t __uni_compose_entry_size = sizeof __uni_compose_entry / sizeof __uni_compose_entry[0];\n\n";
@@ -1344,21 +1359,36 @@
     {
- /* We exclude singletons, decompositions that start with non-starters, and code points from the exclusion table */
+ /* We exclude non-canonical decompositions, singletons,
+ * decompositions that start with non-starters,
+ * and code points from the exclusion table */
         if(

Modified: sandbox/SOC/2009/unicode/libs/unicode/example/compose.cpp
==============================================================================